/* Generated by makegdkalias.pl */

#ifndef DISABLE_VISIBILITY

#include <glib.h>

#ifdef G_HAVE_GNUC_VISIBILITY

#undef IN_FILE
#define IN_FILE defined

#undef IN_HEADER
#define IN_HEADER(x) 1

#if IN_HEADER(__GDK_EVENTS_H__)
#if IN_FILE(__GDK_EVENTS_X11_C__)
#undef gdk_add_client_message_filter 
extern __typeof (gdk_add_client_message_filter) gdk_add_client_message_filter __attribute((alias("IA__gdk_add_client_message_filter"), visibility("default")));

#ifndef GDK_DISABLE_DEPRECATED
#undef gdk_event_get_graphics_expose 
extern __typeof (gdk_event_get_graphics_expose) gdk_event_get_graphics_expose __attribute((alias("IA__gdk_event_get_graphics_expose"), visibility("default")));

#endif
#undef gdk_events_pending 
extern __typeof (gdk_events_pending) gdk_events_pending __attribute((alias("IA__gdk_events_pending"), visibility("default")));

#endif
#endif
#if IN_HEADER(__GDK_TEST_UTILS_H__)
#if IN_FILE(__GDK_TEST_UTILS_X11_C__)
#undef gdk_test_simulate_button 
extern __typeof (gdk_test_simulate_button) gdk_test_simulate_button __attribute((alias("IA__gdk_test_simulate_button"), visibility("default")));

#undef gdk_test_simulate_key 
extern __typeof (gdk_test_simulate_key) gdk_test_simulate_key __attribute((alias("IA__gdk_test_simulate_key"), visibility("default")));

#undef gdk_test_render_sync 
extern __typeof (gdk_test_render_sync) gdk_test_render_sync __attribute((alias("IA__gdk_test_render_sync"), visibility("default")));

#endif
#endif
#if IN_HEADER(__GDK_EVENTS_H__)
#if IN_FILE(__GDK_EVENTS_C__)
#undef gdk_event_copy 
extern __typeof (gdk_event_copy) gdk_event_copy __attribute((alias("IA__gdk_event_copy"), visibility("default")));

#undef gdk_event_free 
extern __typeof (gdk_event_free) gdk_event_free __attribute((alias("IA__gdk_event_free"), visibility("default")));

#undef gdk_event_get 
extern __typeof (gdk_event_get) gdk_event_get __attribute((alias("IA__gdk_event_get"), visibility("default")));

#undef gdk_event_get_axis 
extern __typeof (gdk_event_get_axis) gdk_event_get_axis __attribute((alias("IA__gdk_event_get_axis"), visibility("default")));

#undef gdk_event_get_coords 
extern __typeof (gdk_event_get_coords) gdk_event_get_coords __attribute((alias("IA__gdk_event_get_coords"), visibility("default")));

#undef gdk_event_get_root_coords 
extern __typeof (gdk_event_get_root_coords) gdk_event_get_root_coords __attribute((alias("IA__gdk_event_get_root_coords"), visibility("default")));

#undef gdk_event_get_screen 
extern __typeof (gdk_event_get_screen) gdk_event_get_screen __attribute((alias("IA__gdk_event_get_screen"), visibility("default")));

#undef gdk_event_get_state 
extern __typeof (gdk_event_get_state) gdk_event_get_state __attribute((alias("IA__gdk_event_get_state"), visibility("default")));

#undef gdk_event_get_time 
extern __typeof (gdk_event_get_time) gdk_event_get_time __attribute((alias("IA__gdk_event_get_time"), visibility("default")));

#undef gdk_event_get_type 
extern __typeof (gdk_event_get_type) gdk_event_get_type __attribute((alias("IA__gdk_event_get_type"), visibility("default")));

#undef gdk_event_handler_set 
extern __typeof (gdk_event_handler_set) gdk_event_handler_set __attribute((alias("IA__gdk_event_handler_set"), visibility("default")));

#undef gdk_event_new 
extern __typeof (gdk_event_new) gdk_event_new __attribute((alias("IA__gdk_event_new"), visibility("default")));

#undef gdk_event_peek 
extern __typeof (gdk_event_peek) gdk_event_peek __attribute((alias("IA__gdk_event_peek"), visibility("default")));

#undef gdk_event_put 
extern __typeof (gdk_event_put) gdk_event_put __attribute((alias("IA__gdk_event_put"), visibility("default")));

#undef gdk_event_request_motions 
extern __typeof (gdk_event_request_motions) gdk_event_request_motions __attribute((alias("IA__gdk_event_request_motions"), visibility("default")));

#undef gdk_event_set_screen 
extern __typeof (gdk_event_set_screen) gdk_event_set_screen __attribute((alias("IA__gdk_event_set_screen"), visibility("default")));

#undef gdk_get_show_events 
extern __typeof (gdk_get_show_events) gdk_get_show_events __attribute((alias("IA__gdk_get_show_events"), visibility("default")));

#undef gdk_set_show_events 
extern __typeof (gdk_set_show_events) gdk_set_show_events __attribute((alias("IA__gdk_set_show_events"), visibility("default")));

#undef gdk_setting_get 
extern __typeof (gdk_setting_get) gdk_setting_get __attribute((alias("IA__gdk_setting_get"), visibility("default")));

#endif
#endif
#if IN_HEADER(__GDK_H__)
#if IN_FILE(__GDK_MAIN_X11_C__)
#undef gdk_error_trap_pop 
extern __typeof (gdk_error_trap_pop) gdk_error_trap_pop __attribute((alias("IA__gdk_error_trap_pop"), visibility("default")));

#undef gdk_error_trap_push 
extern __typeof (gdk_error_trap_push) gdk_error_trap_push __attribute((alias("IA__gdk_error_trap_push"), visibility("default")));

#undef gdk_get_display 
extern __typeof (gdk_get_display) gdk_get_display __attribute((alias("IA__gdk_get_display"), visibility("default")));

#ifndef GDK_DISABLE_DEPRECATED
#undef gdk_get_use_xshm 
extern __typeof (gdk_get_use_xshm) gdk_get_use_xshm __attribute((alias("IA__gdk_get_use_xshm"), visibility("default")));

#undef gdk_set_use_xshm 
extern __typeof (gdk_set_use_xshm) gdk_set_use_xshm __attribute((alias("IA__gdk_set_use_xshm"), visibility("default")));

#endif
#undef gdk_keyboard_grab 
extern __typeof (gdk_keyboard_grab) gdk_keyboard_grab __attribute((alias("IA__gdk_keyboard_grab"), visibility("default")));

#endif
#endif
#if IN_HEADER(__GDK_H__)
#if IN_FILE(__GDK_DISPLAY_C__)
#undef gdk_beep 
extern __typeof (gdk_beep) gdk_beep __attribute((alias("IA__gdk_beep"), visibility("default")));

#undef gdk_set_pointer_hooks 
extern __typeof (gdk_set_pointer_hooks) gdk_set_pointer_hooks __attribute((alias("IA__gdk_set_pointer_hooks"), visibility("default")));

#undef gdk_keyboard_ungrab 
extern __typeof (gdk_keyboard_ungrab) gdk_keyboard_ungrab __attribute((alias("IA__gdk_keyboard_ungrab"), visibility("default")));

#undef gdk_pointer_is_grabbed 
extern __typeof (gdk_pointer_is_grabbed) gdk_pointer_is_grabbed __attribute((alias("IA__gdk_pointer_is_grabbed"), visibility("default")));

#undef gdk_pointer_ungrab 
extern __typeof (gdk_pointer_ungrab) gdk_pointer_ungrab __attribute((alias("IA__gdk_pointer_ungrab"), visibility("default")));

#undef gdk_event_send_client_message 
extern __typeof (gdk_event_send_client_message) gdk_event_send_client_message __attribute((alias("IA__gdk_event_send_client_message"), visibility("default")));

#undef gdk_event_send_clientmessage_toall 
extern __typeof (gdk_event_send_clientmessage_toall) gdk_event_send_clientmessage_toall __attribute((alias("IA__gdk_event_send_clientmessage_toall"), visibility("default")));

#undef gdk_keyboard_grab_info_libgtk_only 
extern __typeof (gdk_keyboard_grab_info_libgtk_only) gdk_keyboard_grab_info_libgtk_only __attribute((alias("IA__gdk_keyboard_grab_info_libgtk_only"), visibility("default")));

#undef gdk_pointer_grab_info_libgtk_only 
extern __typeof (gdk_pointer_grab_info_libgtk_only) gdk_pointer_grab_info_libgtk_only __attribute((alias("IA__gdk_pointer_grab_info_libgtk_only"), visibility("default")));

#undef gdk_display_pointer_is_grabbed 
extern __typeof (gdk_display_pointer_is_grabbed) gdk_display_pointer_is_grabbed __attribute((alias("IA__gdk_display_pointer_is_grabbed"), visibility("default")));

#endif
#endif
#if IN_HEADER(__GDK_H__)
#if IN_FILE(__GDK_IM_X11_C__)
#ifndef GDK_DISABLE_DEPRECATED
#undef gdk_mbstowcs 
extern __typeof (gdk_mbstowcs) gdk_mbstowcs __attribute((alias("IA__gdk_mbstowcs"), visibility("default")));

#undef gdk_wcstombs 
extern __typeof (gdk_wcstombs) gdk_wcstombs __attribute((alias("IA__gdk_wcstombs"), visibility("default")));

#undef gdk_set_locale 
extern __typeof (gdk_set_locale) gdk_set_locale __attribute((alias("IA__gdk_set_locale"), visibility("default")));

#endif
#endif
#endif
#if IN_HEADER(__GDK_H__)
#if IN_FILE(__GDK_EVENTS_X11_C__)
#undef gdk_event_send_client_message_for_display 
extern __typeof (gdk_event_send_client_message_for_display) gdk_event_send_client_message_for_display __attribute((alias("IA__gdk_event_send_client_message_for_display"), visibility("default")));

#undef gdk_flush 
extern __typeof (gdk_flush) gdk_flush __attribute((alias("IA__gdk_flush"), visibility("default")));

#endif
#endif
#if IN_HEADER(__GDK_H__)
#if IN_FILE(__GDK_DISPLAY_X11_C__)
#undef gdk_notify_startup_complete 
extern __typeof (gdk_notify_startup_complete) gdk_notify_startup_complete __attribute((alias("IA__gdk_notify_startup_complete"), visibility("default")));

#undef gdk_notify_startup_complete_with_id 
extern __typeof (gdk_notify_startup_complete_with_id) gdk_notify_startup_complete_with_id __attribute((alias("IA__gdk_notify_startup_complete_with_id"), visibility("default")));

#endif
#endif
#if IN_HEADER(__GDK_H__)
#if IN_FILE(__GDK_RECTANGLE_C__)
#undef gdk_rectangle_get_type 
extern __typeof (gdk_rectangle_get_type) gdk_rectangle_get_type __attribute((alias("IA__gdk_rectangle_get_type"), visibility("default")));

#undef gdk_rectangle_intersect 
extern __typeof (gdk_rectangle_intersect) gdk_rectangle_intersect __attribute((alias("IA__gdk_rectangle_intersect"), visibility("default")));

#undef gdk_rectangle_union 
extern __typeof (gdk_rectangle_union) gdk_rectangle_union __attribute((alias("IA__gdk_rectangle_union"), visibility("default")));

#endif
#endif
#if IN_HEADER(__GDK_H__)
#if IN_FILE(__GDK_EVENTS_C__)
#undef gdk_set_double_click_time 
extern __typeof (gdk_set_double_click_time) gdk_set_double_click_time __attribute((alias("IA__gdk_set_double_click_time"), visibility("default")));

#endif
#endif
#if IN_HEADER(__GDK_H__)
#if IN_FILE(__GDK_C__)
#undef gdk_add_option_entries_libgtk_only 
extern __typeof (gdk_add_option_entries_libgtk_only) gdk_add_option_entries_libgtk_only __attribute((alias("IA__gdk_add_option_entries_libgtk_only"), visibility("default")));

#undef gdk_get_display_arg_name 
extern __typeof (gdk_get_display_arg_name) gdk_get_display_arg_name __attribute((alias("IA__gdk_get_display_arg_name"), visibility("default")));

#undef gdk_get_program_class 
extern __typeof (gdk_get_program_class) gdk_get_program_class __attribute((alias("IA__gdk_get_program_class"), visibility("default")));

#undef gdk_init 
extern __typeof (gdk_init) gdk_init __attribute((alias("IA__gdk_init"), visibility("default")));

#undef gdk_init_check 
extern __typeof (gdk_init_check) gdk_init_check __attribute((alias("IA__gdk_init_check"), visibility("default")));

#ifndef GDK_DISABLE_DEPRECATED
#undef gdk_exit 
extern __typeof (gdk_exit) gdk_exit __attribute((alias("IA__gdk_exit"), visibility("default")));

#endif
#undef gdk_pre_parse_libgtk_only 
extern __typeof (gdk_pre_parse_libgtk_only) gdk_pre_parse_libgtk_only __attribute((alias("IA__gdk_pre_parse_libgtk_only"), visibility("default")));

#undef gdk_parse_args 
extern __typeof (gdk_parse_args) gdk_parse_args __attribute((alias("IA__gdk_parse_args"), visibility("default")));

#undef gdk_set_program_class 
extern __typeof (gdk_set_program_class) gdk_set_program_class __attribute((alias("IA__gdk_set_program_class"), visibility("default")));

#undef gdk_threads_enter 
extern __typeof (gdk_threads_enter) gdk_threads_enter __attribute((alias("IA__gdk_threads_enter"), visibility("default")));

#undef gdk_threads_init 
extern __typeof (gdk_threads_init) gdk_threads_init __attribute((alias("IA__gdk_threads_init"), visibility("default")));

#undef gdk_threads_leave 
extern __typeof (gdk_threads_leave) gdk_threads_leave __attribute((alias("IA__gdk_threads_leave"), visibility("default")));

#undef gdk_threads_set_lock_functions 
extern __typeof (gdk_threads_set_lock_functions) gdk_threads_set_lock_functions __attribute((alias("IA__gdk_threads_set_lock_functions"), visibility("default")));

#undef gdk_threads_add_idle 
extern __typeof (gdk_threads_add_idle) gdk_threads_add_idle __attribute((alias("IA__gdk_threads_add_idle"), visibility("default")));

#undef gdk_threads_add_idle_full 
extern __typeof (gdk_threads_add_idle_full) gdk_threads_add_idle_full __attribute((alias("IA__gdk_threads_add_idle_full"), visibility("default")));

#undef gdk_threads_add_timeout 
extern __typeof (gdk_threads_add_timeout) gdk_threads_add_timeout __attribute((alias("IA__gdk_threads_add_timeout"), visibility("default")));

#undef gdk_threads_add_timeout_full 
extern __typeof (gdk_threads_add_timeout_full) gdk_threads_add_timeout_full __attribute((alias("IA__gdk_threads_add_timeout_full"), visibility("default")));

#undef gdk_threads_add_timeout_seconds 
extern __typeof (gdk_threads_add_timeout_seconds) gdk_threads_add_timeout_seconds __attribute((alias("IA__gdk_threads_add_timeout_seconds"), visibility("default")));

#undef gdk_threads_add_timeout_seconds_full 
extern __typeof (gdk_threads_add_timeout_seconds_full) gdk_threads_add_timeout_seconds_full __attribute((alias("IA__gdk_threads_add_timeout_seconds_full"), visibility("default")));

#endif
#endif
#if IN_HEADER(__GDK_H__)
#if IN_FILE(__GDK_EVENTS_C__)
#ifndef GDK_DISABLE_DEPRECATED
#undef gdk_input_add 
extern __typeof (gdk_input_add) gdk_input_add __attribute((alias("IA__gdk_input_add"), visibility("default")));

#undef gdk_input_remove 
extern __typeof (gdk_input_remove) gdk_input_remove __attribute((alias("IA__gdk_input_remove"), visibility("default")));

#undef gdk_input_add_full 
extern __typeof (gdk_input_add_full) gdk_input_add_full __attribute((alias("IA__gdk_input_add_full"), visibility("default")));

#endif
#endif
#endif
#if IN_HEADER(__GDK_H__)
#if IN_FILE(__GDK_SCREEN_C__)
#undef gdk_screen_width 
extern __typeof (gdk_screen_width) gdk_screen_width __attribute((alias("IA__gdk_screen_width"), visibility("default")));

#undef gdk_screen_width_mm 
extern __typeof (gdk_screen_width_mm) gdk_screen_width_mm __attribute((alias("IA__gdk_screen_width_mm"), visibility("default")));

#undef gdk_screen_height 
extern __typeof (gdk_screen_height) gdk_screen_height __attribute((alias("IA__gdk_screen_height"), visibility("default")));

#undef gdk_screen_height_mm 
extern __typeof (gdk_screen_height_mm) gdk_screen_height_mm __attribute((alias("IA__gdk_screen_height_mm"), visibility("default")));

#endif
#endif
#if IN_HEADER(__GDK_PROPERTY_H__)
#if IN_FILE(__GDK_SELECTION_C__)
#ifndef GDK_DISABLE_DEPRECATED
#undef gdk_string_to_compound_text 
extern __typeof (gdk_string_to_compound_text) gdk_string_to_compound_text __attribute((alias("IA__gdk_string_to_compound_text"), visibility("default")));

#undef gdk_text_property_to_text_list 
extern __typeof (gdk_text_property_to_text_list) gdk_text_property_to_text_list __attribute((alias("IA__gdk_text_property_to_text_list"), visibility("default")));

#undef gdk_text_property_to_utf8_list 
extern __typeof (gdk_text_property_to_utf8_list) gdk_text_property_to_utf8_list __attribute((alias("IA__gdk_text_property_to_utf8_list"), visibility("default")));

#undef gdk_utf8_to_compound_text 
extern __typeof (gdk_utf8_to_compound_text) gdk_utf8_to_compound_text __attribute((alias("IA__gdk_utf8_to_compound_text"), visibility("default")));

#endif
#endif
#endif
#if IN_HEADER(__GDK_PROPERTY_H__)
#if IN_FILE(__GDK_PROPERTY_X11_C__)
#undef gdk_atom_intern 
extern __typeof (gdk_atom_intern) gdk_atom_intern __attribute((alias("IA__gdk_atom_intern"), visibility("default")));

#undef gdk_atom_intern_static_string 
extern __typeof (gdk_atom_intern_static_string) gdk_atom_intern_static_string __attribute((alias("IA__gdk_atom_intern_static_string"), visibility("default")));

#undef gdk_atom_name 
extern __typeof (gdk_atom_name) gdk_atom_name __attribute((alias("IA__gdk_atom_name"), visibility("default")));

#undef gdk_property_change 
extern __typeof (gdk_property_change) gdk_property_change __attribute((alias("IA__gdk_property_change"), visibility("default")));

#undef gdk_property_delete 
extern __typeof (gdk_property_delete) gdk_property_delete __attribute((alias("IA__gdk_property_delete"), visibility("default")));

#undef gdk_property_get 
extern __typeof (gdk_property_get) gdk_property_get __attribute((alias("IA__gdk_property_get"), visibility("default")));

#endif
#endif
#if IN_HEADER(__GDK_PROPERTY_H__)
#if IN_FILE(__GDK_SELECTION_X11_C__)
#ifndef GDK_DISABLE_DEPRECATED
#undef gdk_free_compound_text 
extern __typeof (gdk_free_compound_text) gdk_free_compound_text __attribute((alias("IA__gdk_free_compound_text"), visibility("default")));

#undef gdk_free_text_list 
extern __typeof (gdk_free_text_list) gdk_free_text_list __attribute((alias("IA__gdk_free_text_list"), visibility("default")));

#undef gdk_string_to_compound_text_for_display 
extern __typeof (gdk_string_to_compound_text_for_display) gdk_string_to_compound_text_for_display __attribute((alias("IA__gdk_string_to_compound_text_for_display"), visibility("default")));

#undef gdk_text_property_to_text_list_for_display 
extern __typeof (gdk_text_property_to_text_list_for_display) gdk_text_property_to_text_list_for_display __attribute((alias("IA__gdk_text_property_to_text_list_for_display"), visibility("default")));

#undef gdk_utf8_to_compound_text_for_display 
extern __typeof (gdk_utf8_to_compound_text_for_display) gdk_utf8_to_compound_text_for_display __attribute((alias("IA__gdk_utf8_to_compound_text_for_display"), visibility("default")));

#endif
#undef gdk_text_property_to_utf8_list_for_display 
extern __typeof (gdk_text_property_to_utf8_list_for_display) gdk_text_property_to_utf8_list_for_display __attribute((alias("IA__gdk_text_property_to_utf8_list_for_display"), visibility("default")));

#undef gdk_utf8_to_string_target 
extern __typeof (gdk_utf8_to_string_target) gdk_utf8_to_string_target __attribute((alias("IA__gdk_utf8_to_string_target"), visibility("default")));

#endif
#endif
#ifdef GDK_WINDOWING_X11
#if IN_HEADER(__GDK_X_H__)
#if IN_FILE(__GDK_SELECTION_X11_C__)
#undef gdk_x11_display_string_to_compound_text 
extern __typeof (gdk_x11_display_string_to_compound_text) gdk_x11_display_string_to_compound_text __attribute((alias("IA__gdk_x11_display_string_to_compound_text"), visibility("default")));

#undef gdk_x11_display_text_property_to_text_list 
extern __typeof (gdk_x11_display_text_property_to_text_list) gdk_x11_display_text_property_to_text_list __attribute((alias("IA__gdk_x11_display_text_property_to_text_list"), visibility("default")));

#undef gdk_x11_display_utf8_to_compound_text 
extern __typeof (gdk_x11_display_utf8_to_compound_text) gdk_x11_display_utf8_to_compound_text __attribute((alias("IA__gdk_x11_display_utf8_to_compound_text"), visibility("default")));

#undef gdk_x11_free_compound_text 
extern __typeof (gdk_x11_free_compound_text) gdk_x11_free_compound_text __attribute((alias("IA__gdk_x11_free_compound_text"), visibility("default")));

#undef gdk_x11_free_text_list 
extern __typeof (gdk_x11_free_text_list) gdk_x11_free_text_list __attribute((alias("IA__gdk_x11_free_text_list"), visibility("default")));

#endif
#endif
#endif
#if IN_HEADER(__GDK_ENUM_TYPES_H__)
#if IN_FILE(__GDK_ENUM_TYPES_C__)
#undef gdk_rgb_dither_get_type 
extern __typeof (gdk_rgb_dither_get_type) gdk_rgb_dither_get_type __attribute((alias("IA__gdk_rgb_dither_get_type"), visibility("default")));

#undef gdk_drag_protocol_get_type 
extern __typeof (gdk_drag_protocol_get_type) gdk_drag_protocol_get_type __attribute((alias("IA__gdk_drag_protocol_get_type"), visibility("default")));

#undef gdk_input_source_get_type 
extern __typeof (gdk_input_source_get_type) gdk_input_source_get_type __attribute((alias("IA__gdk_input_source_get_type"), visibility("default")));

#undef gdk_input_condition_get_type 
extern __typeof (gdk_input_condition_get_type) gdk_input_condition_get_type __attribute((alias("IA__gdk_input_condition_get_type"), visibility("default")));

#undef gdk_input_mode_get_type 
extern __typeof (gdk_input_mode_get_type) gdk_input_mode_get_type __attribute((alias("IA__gdk_input_mode_get_type"), visibility("default")));

#undef gdk_axis_use_get_type 
extern __typeof (gdk_axis_use_get_type) gdk_axis_use_get_type __attribute((alias("IA__gdk_axis_use_get_type"), visibility("default")));

#undef gdk_byte_order_get_type 
extern __typeof (gdk_byte_order_get_type) gdk_byte_order_get_type __attribute((alias("IA__gdk_byte_order_get_type"), visibility("default")));

#undef gdk_cap_style_get_type 
extern __typeof (gdk_cap_style_get_type) gdk_cap_style_get_type __attribute((alias("IA__gdk_cap_style_get_type"), visibility("default")));

#undef gdk_crossing_mode_get_type 
extern __typeof (gdk_crossing_mode_get_type) gdk_crossing_mode_get_type __attribute((alias("IA__gdk_crossing_mode_get_type"), visibility("default")));

#undef gdk_extension_mode_get_type 
extern __typeof (gdk_extension_mode_get_type) gdk_extension_mode_get_type __attribute((alias("IA__gdk_extension_mode_get_type"), visibility("default")));

#undef gdk_event_mask_get_type 
extern __typeof (gdk_event_mask_get_type) gdk_event_mask_get_type __attribute((alias("IA__gdk_event_mask_get_type"), visibility("default")));

#undef gdk_event_type_get_type 
extern __typeof (gdk_event_type_get_type) gdk_event_type_get_type __attribute((alias("IA__gdk_event_type_get_type"), visibility("default")));

#undef gdk_fill_get_type 
extern __typeof (gdk_fill_get_type) gdk_fill_get_type __attribute((alias("IA__gdk_fill_get_type"), visibility("default")));

#ifndef GDK_DISABLE_DEPRECATED
#undef gdk_fill_rule_get_type 
extern __typeof (gdk_fill_rule_get_type) gdk_fill_rule_get_type __attribute((alias("IA__gdk_fill_rule_get_type"), visibility("default")));

#endif
#undef gdk_filter_return_get_type 
extern __typeof (gdk_filter_return_get_type) gdk_filter_return_get_type __attribute((alias("IA__gdk_filter_return_get_type"), visibility("default")));

#undef gdk_function_get_type 
extern __typeof (gdk_function_get_type) gdk_function_get_type __attribute((alias("IA__gdk_function_get_type"), visibility("default")));

#undef gdk_grab_status_get_type 
extern __typeof (gdk_grab_status_get_type) gdk_grab_status_get_type __attribute((alias("IA__gdk_grab_status_get_type"), visibility("default")));

#undef gdk_gravity_get_type 
extern __typeof (gdk_gravity_get_type) gdk_gravity_get_type __attribute((alias("IA__gdk_gravity_get_type"), visibility("default")));

#undef gdk_join_style_get_type 
extern __typeof (gdk_join_style_get_type) gdk_join_style_get_type __attribute((alias("IA__gdk_join_style_get_type"), visibility("default")));

#undef gdk_line_style_get_type 
extern __typeof (gdk_line_style_get_type) gdk_line_style_get_type __attribute((alias("IA__gdk_line_style_get_type"), visibility("default")));

#undef gdk_modifier_type_get_type 
extern __typeof (gdk_modifier_type_get_type) gdk_modifier_type_get_type __attribute((alias("IA__gdk_modifier_type_get_type"), visibility("default")));

#undef gdk_notify_type_get_type 
extern __typeof (gdk_notify_type_get_type) gdk_notify_type_get_type __attribute((alias("IA__gdk_notify_type_get_type"), visibility("default")));

#undef gdk_overlap_type_get_type 
extern __typeof (gdk_overlap_type_get_type) gdk_overlap_type_get_type __attribute((alias("IA__gdk_overlap_type_get_type"), visibility("default")));

#undef gdk_owner_change_get_type 
extern __typeof (gdk_owner_change_get_type) gdk_owner_change_get_type __attribute((alias("IA__gdk_owner_change_get_type"), visibility("default")));

#undef gdk_property_state_get_type 
extern __typeof (gdk_property_state_get_type) gdk_property_state_get_type __attribute((alias("IA__gdk_property_state_get_type"), visibility("default")));

#undef gdk_prop_mode_get_type 
extern __typeof (gdk_prop_mode_get_type) gdk_prop_mode_get_type __attribute((alias("IA__gdk_prop_mode_get_type"), visibility("default")));

#undef gdk_scroll_direction_get_type 
extern __typeof (gdk_scroll_direction_get_type) gdk_scroll_direction_get_type __attribute((alias("IA__gdk_scroll_direction_get_type"), visibility("default")));

#undef gdk_setting_action_get_type 
extern __typeof (gdk_setting_action_get_type) gdk_setting_action_get_type __attribute((alias("IA__gdk_setting_action_get_type"), visibility("default")));

#undef gdk_status_get_type 
extern __typeof (gdk_status_get_type) gdk_status_get_type __attribute((alias("IA__gdk_status_get_type"), visibility("default")));

#undef gdk_subwindow_mode_get_type 
extern __typeof (gdk_subwindow_mode_get_type) gdk_subwindow_mode_get_type __attribute((alias("IA__gdk_subwindow_mode_get_type"), visibility("default")));

#undef gdk_visibility_state_get_type 
extern __typeof (gdk_visibility_state_get_type) gdk_visibility_state_get_type __attribute((alias("IA__gdk_visibility_state_get_type"), visibility("default")));

#undef gdk_wm_decoration_get_type 
extern __typeof (gdk_wm_decoration_get_type) gdk_wm_decoration_get_type __attribute((alias("IA__gdk_wm_decoration_get_type"), visibility("default")));

#undef gdk_wm_function_get_type 
extern __typeof (gdk_wm_function_get_type) gdk_wm_function_get_type __attribute((alias("IA__gdk_wm_function_get_type"), visibility("default")));

#undef gdk_font_type_get_type 
extern __typeof (gdk_font_type_get_type) gdk_font_type_get_type __attribute((alias("IA__gdk_font_type_get_type"), visibility("default")));

#undef gdk_cursor_type_get_type 
extern __typeof (gdk_cursor_type_get_type) gdk_cursor_type_get_type __attribute((alias("IA__gdk_cursor_type_get_type"), visibility("default")));

#undef gdk_drag_action_get_type 
extern __typeof (gdk_drag_action_get_type) gdk_drag_action_get_type __attribute((alias("IA__gdk_drag_action_get_type"), visibility("default")));

#undef gdk_gc_values_mask_get_type 
extern __typeof (gdk_gc_values_mask_get_type) gdk_gc_values_mask_get_type __attribute((alias("IA__gdk_gc_values_mask_get_type"), visibility("default")));

#undef gdk_window_attributes_type_get_type 
extern __typeof (gdk_window_attributes_type_get_type) gdk_window_attributes_type_get_type __attribute((alias("IA__gdk_window_attributes_type_get_type"), visibility("default")));

#undef gdk_window_class_get_type 
extern __typeof (gdk_window_class_get_type) gdk_window_class_get_type __attribute((alias("IA__gdk_window_class_get_type"), visibility("default")));

#undef gdk_window_edge_get_type 
extern __typeof (gdk_window_edge_get_type) gdk_window_edge_get_type __attribute((alias("IA__gdk_window_edge_get_type"), visibility("default")));

#undef gdk_window_hints_get_type 
extern __typeof (gdk_window_hints_get_type) gdk_window_hints_get_type __attribute((alias("IA__gdk_window_hints_get_type"), visibility("default")));

#undef gdk_window_state_get_type 
extern __typeof (gdk_window_state_get_type) gdk_window_state_get_type __attribute((alias("IA__gdk_window_state_get_type"), visibility("default")));

#undef gdk_window_type_get_type 
extern __typeof (gdk_window_type_get_type) gdk_window_type_get_type __attribute((alias("IA__gdk_window_type_get_type"), visibility("default")));

#undef gdk_window_type_hint_get_type 
extern __typeof (gdk_window_type_hint_get_type) gdk_window_type_hint_get_type __attribute((alias("IA__gdk_window_type_hint_get_type"), visibility("default")));

#undef gdk_image_type_get_type 
extern __typeof (gdk_image_type_get_type) gdk_image_type_get_type __attribute((alias("IA__gdk_image_type_get_type"), visibility("default")));

#undef gdk_visual_type_get_type 
extern __typeof (gdk_visual_type_get_type) gdk_visual_type_get_type __attribute((alias("IA__gdk_visual_type_get_type"), visibility("default")));

#endif
#endif
#if IN_HEADER(__GDK_FONT_H__)
#if IN_FILE(__GDK_FONT_C__)
#ifndef GDK_DISABLE_DEPRECATED
#undef gdk_font_from_description 
extern __typeof (gdk_font_from_description) gdk_font_from_description __attribute((alias("IA__gdk_font_from_description"), visibility("default")));

#endif
#undef gdk_font_get_type 
extern __typeof (gdk_font_get_type) gdk_font_get_type __attribute((alias("IA__gdk_font_get_type"), visibility("default")));

#undef gdk_font_ref 
extern __typeof (gdk_font_ref) gdk_font_ref __attribute((alias("IA__gdk_font_ref"), visibility("default")));

#undef gdk_font_unref 
extern __typeof (gdk_font_unref) gdk_font_unref __attribute((alias("IA__gdk_font_unref"), visibility("default")));

#ifndef GDK_DISABLE_DEPRECATED
#undef gdk_font_load 
extern __typeof (gdk_font_load) gdk_font_load __attribute((alias("IA__gdk_font_load"), visibility("default")));

#undef gdk_string_width 
extern __typeof (gdk_string_width) gdk_string_width __attribute((alias("IA__gdk_string_width"), visibility("default")));

#undef gdk_char_width 
extern __typeof (gdk_char_width) gdk_char_width __attribute((alias("IA__gdk_char_width"), visibility("default")));

#undef gdk_char_width_wc 
extern __typeof (gdk_char_width_wc) gdk_char_width_wc __attribute((alias("IA__gdk_char_width_wc"), visibility("default")));

#undef gdk_string_measure 
extern __typeof (gdk_string_measure) gdk_string_measure __attribute((alias("IA__gdk_string_measure"), visibility("default")));

#undef gdk_text_measure 
extern __typeof (gdk_text_measure) gdk_text_measure __attribute((alias("IA__gdk_text_measure"), visibility("default")));

#undef gdk_char_measure 
extern __typeof (gdk_char_measure) gdk_char_measure __attribute((alias("IA__gdk_char_measure"), visibility("default")));

#undef gdk_string_height 
extern __typeof (gdk_string_height) gdk_string_height __attribute((alias("IA__gdk_string_height"), visibility("default")));

#undef gdk_text_height 
extern __typeof (gdk_text_height) gdk_text_height __attribute((alias("IA__gdk_text_height"), visibility("default")));

#undef gdk_char_height 
extern __typeof (gdk_char_height) gdk_char_height __attribute((alias("IA__gdk_char_height"), visibility("default")));

#undef gdk_string_extents 
extern __typeof (gdk_string_extents) gdk_string_extents __attribute((alias("IA__gdk_string_extents"), visibility("default")));

#endif
#endif
#endif
#if IN_HEADER(__GDK_FONT_H__)
#if IN_FILE(__GDK_FONT_X11_C__)
#ifndef GDK_DISABLE_DEPRECATED
#undef gdk_text_extents 
extern __typeof (gdk_text_extents) gdk_text_extents __attribute((alias("IA__gdk_text_extents"), visibility("default")));

#undef gdk_text_extents_wc 
extern __typeof (gdk_text_extents_wc) gdk_text_extents_wc __attribute((alias("IA__gdk_text_extents_wc"), visibility("default")));

#undef gdk_text_width 
extern __typeof (gdk_text_width) gdk_text_width __attribute((alias("IA__gdk_text_width"), visibility("default")));

#undef gdk_text_width_wc 
extern __typeof (gdk_text_width_wc) gdk_text_width_wc __attribute((alias("IA__gdk_text_width_wc"), visibility("default")));

#undef gdk_font_get_display 
extern __typeof (gdk_font_get_display) gdk_font_get_display __attribute((alias("IA__gdk_font_get_display"), visibility("default")));

#undef gdk_fontset_load 
extern __typeof (gdk_fontset_load) gdk_fontset_load __attribute((alias("IA__gdk_fontset_load"), visibility("default")));

#endif
#undef gdk_font_id 
extern __typeof (gdk_font_id) gdk_font_id __attribute((alias("IA__gdk_font_id"), visibility("default")));

#undef gdk_font_equal 
extern __typeof (gdk_font_equal) gdk_font_equal __attribute((alias("IA__gdk_font_equal"), visibility("default")));

#undef gdk_font_load_for_display 
extern __typeof (gdk_font_load_for_display) gdk_font_load_for_display __attribute((alias("IA__gdk_font_load_for_display"), visibility("default")));

#undef gdk_font_from_description_for_display 
extern __typeof (gdk_font_from_description_for_display) gdk_font_from_description_for_display __attribute((alias("IA__gdk_font_from_description_for_display"), visibility("default")));

#undef gdk_fontset_load_for_display 
extern __typeof (gdk_fontset_load_for_display) gdk_fontset_load_for_display __attribute((alias("IA__gdk_fontset_load_for_display"), visibility("default")));

#endif
#endif
#if IN_HEADER(__GDK_CAIRO_H__)
#if IN_FILE(__GDK_CAIRO_C__)
#undef gdk_cairo_create 
extern __typeof (gdk_cairo_create) gdk_cairo_create __attribute((alias("IA__gdk_cairo_create"), visibility("default")));

#undef gdk_cairo_reset_clip 
extern __typeof (gdk_cairo_reset_clip) gdk_cairo_reset_clip __attribute((alias("IA__gdk_cairo_reset_clip"), visibility("default")));

#undef gdk_cairo_set_source_color 
extern __typeof (gdk_cairo_set_source_color) gdk_cairo_set_source_color __attribute((alias("IA__gdk_cairo_set_source_color"), visibility("default")));

#undef gdk_cairo_set_source_pixbuf 
extern __typeof (gdk_cairo_set_source_pixbuf) gdk_cairo_set_source_pixbuf __attribute((alias("IA__gdk_cairo_set_source_pixbuf"), visibility("default")));

#undef gdk_cairo_set_source_pixmap 
extern __typeof (gdk_cairo_set_source_pixmap) gdk_cairo_set_source_pixmap __attribute((alias("IA__gdk_cairo_set_source_pixmap"), visibility("default")));

#undef gdk_cairo_set_source_window 
extern __typeof (gdk_cairo_set_source_window) gdk_cairo_set_source_window __attribute((alias("IA__gdk_cairo_set_source_window"), visibility("default")));

#undef gdk_cairo_rectangle 
extern __typeof (gdk_cairo_rectangle) gdk_cairo_rectangle __attribute((alias("IA__gdk_cairo_rectangle"), visibility("default")));

#undef gdk_cairo_region 
extern __typeof (gdk_cairo_region) gdk_cairo_region __attribute((alias("IA__gdk_cairo_region"), visibility("default")));

#endif
#endif
#if IN_HEADER(__GDK_COLOR_H__)
#if IN_FILE(__GDK_COLOR_C__)
#ifndef GDK_DISABLE_DEPRECATED
#undef gdk_colors_store 
extern __typeof (gdk_colors_store) gdk_colors_store __attribute((alias("IA__gdk_colors_store"), visibility("default")));

#undef gdk_color_white 
extern __typeof (gdk_color_white) gdk_color_white __attribute((alias("IA__gdk_color_white"), visibility("default")));

#undef gdk_color_black 
extern __typeof (gdk_color_black) gdk_color_black __attribute((alias("IA__gdk_color_black"), visibility("default")));

#undef gdk_color_alloc 
extern __typeof (gdk_color_alloc) gdk_color_alloc __attribute((alias("IA__gdk_color_alloc"), visibility("default")));

#endif
#undef gdk_color_copy 
extern __typeof (gdk_color_copy) gdk_color_copy __attribute((alias("IA__gdk_color_copy"), visibility("default")));

#undef gdk_color_equal 
extern __typeof (gdk_color_equal) gdk_color_equal __attribute((alias("IA__gdk_color_equal"), visibility("default")));

#undef gdk_color_free 
extern __typeof (gdk_color_free) gdk_color_free __attribute((alias("IA__gdk_color_free"), visibility("default")));

#undef gdk_color_get_type 
extern __typeof (gdk_color_get_type) gdk_color_get_type __attribute((alias("IA__gdk_color_get_type"), visibility("default")));

#undef gdk_color_hash 
extern __typeof (gdk_color_hash) gdk_color_hash __attribute((alias("IA__gdk_color_hash"), visibility("default")));

#undef gdk_colormap_alloc_color 
extern __typeof (gdk_colormap_alloc_color) gdk_colormap_alloc_color __attribute((alias("IA__gdk_colormap_alloc_color"), visibility("default")));

#undef gdk_colormap_get_system 
extern __typeof (gdk_colormap_get_system) gdk_colormap_get_system __attribute((alias("IA__gdk_colormap_get_system"), visibility("default")));

#undef gdk_colormap_get_visual 
extern __typeof (gdk_colormap_get_visual) gdk_colormap_get_visual __attribute((alias("IA__gdk_colormap_get_visual"), visibility("default")));

#ifndef GDK_DISABLE_DEPRECATED
#undef gdk_colormap_ref 
extern __typeof (gdk_colormap_ref) gdk_colormap_ref __attribute((alias("IA__gdk_colormap_ref"), visibility("default")));

#undef gdk_colormap_unref 
extern __typeof (gdk_colormap_unref) gdk_colormap_unref __attribute((alias("IA__gdk_colormap_unref"), visibility("default")));

#endif
#undef gdk_color_parse 
extern __typeof (gdk_color_parse) gdk_color_parse __attribute((alias("IA__gdk_color_parse"), visibility("default")));

#undef gdk_color_to_string 
extern __typeof (gdk_color_to_string) gdk_color_to_string __attribute((alias("IA__gdk_color_to_string"), visibility("default")));

#endif
#endif
#if IN_HEADER(__GDK_COLOR_H__)
#if IN_FILE(__GDK_COLOR_X11_C__)
#undef gdk_colormap_new 
extern __typeof (gdk_colormap_new) gdk_colormap_new __attribute((alias("IA__gdk_colormap_new"), visibility("default")));

#undef gdk_colormap_get_type 
extern __typeof (gdk_colormap_get_type) gdk_colormap_get_type __attribute((alias("IA__gdk_colormap_get_type"), visibility("default")));

#ifndef GDK_DISABLE_DEPRECATED
#undef gdk_colormap_change 
extern __typeof (gdk_colormap_change) gdk_colormap_change __attribute((alias("IA__gdk_colormap_change"), visibility("default")));

#undef gdk_colors_alloc 
extern __typeof (gdk_colors_alloc) gdk_colors_alloc __attribute((alias("IA__gdk_colors_alloc"), visibility("default")));

#undef gdk_colors_free 
extern __typeof (gdk_colors_free) gdk_colors_free __attribute((alias("IA__gdk_colors_free"), visibility("default")));

#undef gdk_colormap_get_system_size 
extern __typeof (gdk_colormap_get_system_size) gdk_colormap_get_system_size __attribute((alias("IA__gdk_colormap_get_system_size"), visibility("default")));

#undef gdk_color_change 
extern __typeof (gdk_color_change) gdk_color_change __attribute((alias("IA__gdk_color_change"), visibility("default")));

#endif
#undef gdk_colormap_alloc_colors 
extern __typeof (gdk_colormap_alloc_colors) gdk_colormap_alloc_colors __attribute((alias("IA__gdk_colormap_alloc_colors"), visibility("default")));

#undef gdk_colormap_free_colors 
extern __typeof (gdk_colormap_free_colors) gdk_colormap_free_colors __attribute((alias("IA__gdk_colormap_free_colors"), visibility("default")));

#undef gdk_colormap_query_color 
extern __typeof (gdk_colormap_query_color) gdk_colormap_query_color __attribute((alias("IA__gdk_colormap_query_color"), visibility("default")));

#undef gdk_colormap_get_screen 
extern __typeof (gdk_colormap_get_screen) gdk_colormap_get_screen __attribute((alias("IA__gdk_colormap_get_screen"), visibility("default")));

#endif
#endif
#if IN_HEADER(__GDK_CURSOR_H__)
#if IN_FILE(__GDK_CURSOR_C__)
#undef gdk_cursor_get_type 
extern __typeof (gdk_cursor_get_type) gdk_cursor_get_type __attribute((alias("IA__gdk_cursor_get_type"), visibility("default")));

#undef gdk_cursor_get_cursor_type 
extern __typeof (gdk_cursor_get_cursor_type) gdk_cursor_get_cursor_type __attribute((alias("IA__gdk_cursor_get_cursor_type"), visibility("default")));

#undef gdk_cursor_new 
extern __typeof (gdk_cursor_new) gdk_cursor_new __attribute((alias("IA__gdk_cursor_new"), visibility("default")));

#undef gdk_cursor_ref 
extern __typeof (gdk_cursor_ref) gdk_cursor_ref __attribute((alias("IA__gdk_cursor_ref"), visibility("default")));

#undef gdk_cursor_unref 
extern __typeof (gdk_cursor_unref) gdk_cursor_unref __attribute((alias("IA__gdk_cursor_unref"), visibility("default")));

#endif
#endif
#if IN_HEADER(__GDK_CURSOR_H__)
#if IN_FILE(__GDK_CURSOR_X11_C__)
#undef gdk_cursor_get_display 
extern __typeof (gdk_cursor_get_display) gdk_cursor_get_display __attribute((alias("IA__gdk_cursor_get_display"), visibility("default")));

#undef gdk_cursor_new_for_display 
extern __typeof (gdk_cursor_new_for_display) gdk_cursor_new_for_display __attribute((alias("IA__gdk_cursor_new_for_display"), visibility("default")));

#undef gdk_cursor_new_from_pixbuf 
extern __typeof (gdk_cursor_new_from_pixbuf) gdk_cursor_new_from_pixbuf __attribute((alias("IA__gdk_cursor_new_from_pixbuf"), visibility("default")));

#undef gdk_cursor_new_from_pixmap 
extern __typeof (gdk_cursor_new_from_pixmap) gdk_cursor_new_from_pixmap __attribute((alias("IA__gdk_cursor_new_from_pixmap"), visibility("default")));

#undef gdk_cursor_new_from_name 
extern __typeof (gdk_cursor_new_from_name) gdk_cursor_new_from_name __attribute((alias("IA__gdk_cursor_new_from_name"), visibility("default")));

#undef gdk_cursor_get_image 
extern __typeof (gdk_cursor_get_image) gdk_cursor_get_image __attribute((alias("IA__gdk_cursor_get_image"), visibility("default")));

#endif
#endif
#if IN_HEADER(__GDK_INPUT_H__)
#if IN_FILE(__GDK_INPUT_C__)
#undef gdk_device_free_history 
extern __typeof (gdk_device_free_history) gdk_device_free_history __attribute((alias("IA__gdk_device_free_history"), visibility("default")));

#undef gdk_device_get_axis 
extern __typeof (gdk_device_get_axis) gdk_device_get_axis __attribute((alias("IA__gdk_device_get_axis"), visibility("default")));

#undef gdk_device_get_axis_use 
extern __typeof (gdk_device_get_axis_use) gdk_device_get_axis_use __attribute((alias("IA__gdk_device_get_axis_use"), visibility("default")));

#undef gdk_device_get_has_cursor 
extern __typeof (gdk_device_get_has_cursor) gdk_device_get_has_cursor __attribute((alias("IA__gdk_device_get_has_cursor"), visibility("default")));

#undef gdk_device_get_history 
extern __typeof (gdk_device_get_history) gdk_device_get_history __attribute((alias("IA__gdk_device_get_history"), visibility("default")));

#undef gdk_device_get_key 
extern __typeof (gdk_device_get_key) gdk_device_get_key __attribute((alias("IA__gdk_device_get_key"), visibility("default")));

#undef gdk_device_get_mode 
extern __typeof (gdk_device_get_mode) gdk_device_get_mode __attribute((alias("IA__gdk_device_get_mode"), visibility("default")));

#undef gdk_device_get_name 
extern __typeof (gdk_device_get_name) gdk_device_get_name __attribute((alias("IA__gdk_device_get_name"), visibility("default")));

#undef gdk_device_get_n_axes 
extern __typeof (gdk_device_get_n_axes) gdk_device_get_n_axes __attribute((alias("IA__gdk_device_get_n_axes"), visibility("default")));

#undef gdk_device_get_n_keys 
extern __typeof (gdk_device_get_n_keys) gdk_device_get_n_keys __attribute((alias("IA__gdk_device_get_n_keys"), visibility("default")));

#undef gdk_device_get_source 
extern __typeof (gdk_device_get_source) gdk_device_get_source __attribute((alias("IA__gdk_device_get_source"), visibility("default")));

#undef gdk_device_get_type 
extern __typeof (gdk_device_get_type) gdk_device_get_type __attribute((alias("IA__gdk_device_get_type"), visibility("default")));

#undef gdk_device_set_axis_use 
extern __typeof (gdk_device_set_axis_use) gdk_device_set_axis_use __attribute((alias("IA__gdk_device_set_axis_use"), visibility("default")));

#undef gdk_device_set_key 
extern __typeof (gdk_device_set_key) gdk_device_set_key __attribute((alias("IA__gdk_device_set_key"), visibility("default")));

#undef gdk_device_set_source 
extern __typeof (gdk_device_set_source) gdk_device_set_source __attribute((alias("IA__gdk_device_set_source"), visibility("default")));

#undef gdk_devices_list 
extern __typeof (gdk_devices_list) gdk_devices_list __attribute((alias("IA__gdk_devices_list"), visibility("default")));

#undef gdk_input_set_extension_events 
extern __typeof (gdk_input_set_extension_events) gdk_input_set_extension_events __attribute((alias("IA__gdk_input_set_extension_events"), visibility("default")));

#endif
#endif
#if IN_HEADER(__GDK_INPUT_H__)
#if IN_FILE(__GDK_DISPLAY_C__)
#undef gdk_device_get_core_pointer 
extern __typeof (gdk_device_get_core_pointer) gdk_device_get_core_pointer __attribute((alias("IA__gdk_device_get_core_pointer"), visibility("default")));

#endif
#endif
#if IN_HEADER(__GDK_INPUT_H__)
#if IN_FILE(__GDK_INPUT_X11_C__)
#undef gdk_device_get_state 
extern __typeof (gdk_device_get_state) gdk_device_get_state __attribute((alias("IA__gdk_device_get_state"), visibility("default")));

#endif
#endif
#if IN_HEADER(__GDK_INPUT_H__)
#if IN_FILE(__GDK_INPUT_XFREE_C__)
#undef gdk_device_set_mode 
extern __typeof (gdk_device_set_mode) gdk_device_set_mode __attribute((alias("IA__gdk_device_set_mode"), visibility("default")));

#endif
#endif
#if IN_HEADER(__GDK_INPUT_H__)
#if IN_FILE(__GDK_INPUT_NONE_C__)
#undef gdk_device_get_state 
extern __typeof (gdk_device_get_state) gdk_device_get_state __attribute((alias("IA__gdk_device_get_state"), visibility("default")));

#undef gdk_device_set_mode 
extern __typeof (gdk_device_set_mode) gdk_device_set_mode __attribute((alias("IA__gdk_device_set_mode"), visibility("default")));

#endif
#endif
#if IN_HEADER(__GDK_DISPLAY_H__)
#if IN_FILE(__GDK_EVENTS_X11_C__)
#undef gdk_display_add_client_message_filter 
extern __typeof (gdk_display_add_client_message_filter) gdk_display_add_client_message_filter __attribute((alias("IA__gdk_display_add_client_message_filter"), visibility("default")));

#endif
#endif
#if IN_HEADER(__GDK_DISPLAY_H__)
#if IN_FILE(__GDK_DISPLAY_C__)
#undef gdk_display_close 
extern __typeof (gdk_display_close) gdk_display_close __attribute((alias("IA__gdk_display_close"), visibility("default")));

#undef gdk_display_get_core_pointer 
extern __typeof (gdk_display_get_core_pointer) gdk_display_get_core_pointer __attribute((alias("IA__gdk_display_get_core_pointer"), visibility("default")));

#undef gdk_display_get_event 
extern __typeof (gdk_display_get_event) gdk_display_get_event __attribute((alias("IA__gdk_display_get_event"), visibility("default")));

#undef gdk_display_get_pointer 
extern __typeof (gdk_display_get_pointer) gdk_display_get_pointer __attribute((alias("IA__gdk_display_get_pointer"), visibility("default")));

#undef gdk_display_get_type 
extern __typeof (gdk_display_get_type) gdk_display_get_type __attribute((alias("IA__gdk_display_get_type"), visibility("default")));

#undef gdk_display_get_window_at_pointer 
extern __typeof (gdk_display_get_window_at_pointer) gdk_display_get_window_at_pointer __attribute((alias("IA__gdk_display_get_window_at_pointer"), visibility("default")));

#undef gdk_display_is_closed 
extern __typeof (gdk_display_is_closed) gdk_display_is_closed __attribute((alias("IA__gdk_display_is_closed"), visibility("default")));

#undef gdk_display_peek_event 
extern __typeof (gdk_display_peek_event) gdk_display_peek_event __attribute((alias("IA__gdk_display_peek_event"), visibility("default")));

#undef gdk_display_put_event 
extern __typeof (gdk_display_put_event) gdk_display_put_event __attribute((alias("IA__gdk_display_put_event"), visibility("default")));

#undef gdk_display_set_pointer_hooks 
extern __typeof (gdk_display_set_pointer_hooks) gdk_display_set_pointer_hooks __attribute((alias("IA__gdk_display_set_pointer_hooks"), visibility("default")));

#endif
#endif
#if IN_HEADER(__GDK_DISPLAY_H__)
#if IN_FILE(__GDK_WINDOW_X11_C__)
#undef gdk_display_warp_pointer 
extern __typeof (gdk_display_warp_pointer) gdk_display_warp_pointer __attribute((alias("IA__gdk_display_warp_pointer"), visibility("default")));

#endif
#endif
#if IN_HEADER(__GDK_DISPLAY_H__)
#if IN_FILE(__GDK_DISPLAY_MANAGER_C__)
#undef gdk_display_get_default 
extern __typeof (gdk_display_get_default) gdk_display_get_default __attribute((alias("IA__gdk_display_get_default"), visibility("default")));

#endif
#endif
#if IN_HEADER(__GDK_DISPLAY_H__)
#if IN_FILE(__GDK_CURSOR_X11_C__)
#undef gdk_display_get_default_cursor_size 
extern __typeof (gdk_display_get_default_cursor_size) gdk_display_get_default_cursor_size __attribute((alias("IA__gdk_display_get_default_cursor_size"), visibility("default")));

#undef gdk_display_get_maximal_cursor_size 
extern __typeof (gdk_display_get_maximal_cursor_size) gdk_display_get_maximal_cursor_size __attribute((alias("IA__gdk_display_get_maximal_cursor_size"), visibility("default")));

#undef gdk_display_supports_cursor_alpha 
extern __typeof (gdk_display_supports_cursor_alpha) gdk_display_supports_cursor_alpha __attribute((alias("IA__gdk_display_supports_cursor_alpha"), visibility("default")));

#undef gdk_display_supports_cursor_color 
extern __typeof (gdk_display_supports_cursor_color) gdk_display_supports_cursor_color __attribute((alias("IA__gdk_display_supports_cursor_color"), visibility("default")));

#endif
#endif
#if IN_HEADER(__GDK_DISPLAY_H__)
#if IN_FILE(__GDK_DISPLAY_X11_C__)
#undef gdk_display_beep 
extern __typeof (gdk_display_beep) gdk_display_beep __attribute((alias("IA__gdk_display_beep"), visibility("default")));

#undef gdk_display_sync 
extern __typeof (gdk_display_sync) gdk_display_sync __attribute((alias("IA__gdk_display_sync"), visibility("default")));

#undef gdk_display_flush 
extern __typeof (gdk_display_flush) gdk_display_flush __attribute((alias("IA__gdk_display_flush"), visibility("default")));

#undef gdk_display_get_default_group 
extern __typeof (gdk_display_get_default_group) gdk_display_get_default_group __attribute((alias("IA__gdk_display_get_default_group"), visibility("default")));

#undef gdk_display_get_default_screen 
extern __typeof (gdk_display_get_default_screen) gdk_display_get_default_screen __attribute((alias("IA__gdk_display_get_default_screen"), visibility("default")));

#undef gdk_display_get_name 
extern __typeof (gdk_display_get_name) gdk_display_get_name __attribute((alias("IA__gdk_display_get_name"), visibility("default")));

#undef gdk_display_get_n_screens 
extern __typeof (gdk_display_get_n_screens) gdk_display_get_n_screens __attribute((alias("IA__gdk_display_get_n_screens"), visibility("default")));

#undef gdk_display_get_screen 
extern __typeof (gdk_display_get_screen) gdk_display_get_screen __attribute((alias("IA__gdk_display_get_screen"), visibility("default")));

#undef gdk_display_pointer_ungrab 
extern __typeof (gdk_display_pointer_ungrab) gdk_display_pointer_ungrab __attribute((alias("IA__gdk_display_pointer_ungrab"), visibility("default")));

#undef gdk_display_keyboard_ungrab 
extern __typeof (gdk_display_keyboard_ungrab) gdk_display_keyboard_ungrab __attribute((alias("IA__gdk_display_keyboard_ungrab"), visibility("default")));

#undef gdk_display_open 
extern __typeof (gdk_display_open) gdk_display_open __attribute((alias("IA__gdk_display_open"), visibility("default")));

#undef gdk_display_request_selection_notification 
extern __typeof (gdk_display_request_selection_notification) gdk_display_request_selection_notification __attribute((alias("IA__gdk_display_request_selection_notification"), visibility("default")));

#undef gdk_display_store_clipboard 
extern __typeof (gdk_display_store_clipboard) gdk_display_store_clipboard __attribute((alias("IA__gdk_display_store_clipboard"), visibility("default")));

#undef gdk_display_supports_clipboard_persistence 
extern __typeof (gdk_display_supports_clipboard_persistence) gdk_display_supports_clipboard_persistence __attribute((alias("IA__gdk_display_supports_clipboard_persistence"), visibility("default")));

#undef gdk_display_supports_selection_notification 
extern __typeof (gdk_display_supports_selection_notification) gdk_display_supports_selection_notification __attribute((alias("IA__gdk_display_supports_selection_notification"), visibility("default")));

#undef gdk_display_supports_shapes 
extern __typeof (gdk_display_supports_shapes) gdk_display_supports_shapes __attribute((alias("IA__gdk_display_supports_shapes"), visibility("default")));

#undef gdk_display_supports_input_shapes 
extern __typeof (gdk_display_supports_input_shapes) gdk_display_supports_input_shapes __attribute((alias("IA__gdk_display_supports_input_shapes"), visibility("default")));

#undef gdk_display_supports_composite 
extern __typeof (gdk_display_supports_composite) gdk_display_supports_composite __attribute((alias("IA__gdk_display_supports_composite"), visibility("default")));

#endif
#endif
#if IN_HEADER(__GDK_DISPLAY_H__)
#if IN_FILE(__GDK_INPUT_C__)
#undef gdk_display_list_devices 
extern __typeof (gdk_display_list_devices) gdk_display_list_devices __attribute((alias("IA__gdk_display_list_devices"), visibility("default")));

#endif
#endif
#if IN_HEADER(__GDK_DISPLAY_H__)
#if IN_FILE(__GDK_C__)
#undef gdk_display_open_default_libgtk_only 
extern __typeof (gdk_display_open_default_libgtk_only) gdk_display_open_default_libgtk_only __attribute((alias("IA__gdk_display_open_default_libgtk_only"), visibility("default")));

#endif
#endif
#if IN_HEADER(__GDK_DISPLAY_H__)
#if IN_FILE(__GDK_EVENTS_C__)
#undef gdk_display_set_double_click_distance 
extern __typeof (gdk_display_set_double_click_distance) gdk_display_set_double_click_distance __attribute((alias("IA__gdk_display_set_double_click_distance"), visibility("default")));

#undef gdk_display_set_double_click_time 
extern __typeof (gdk_display_set_double_click_time) gdk_display_set_double_click_time __attribute((alias("IA__gdk_display_set_double_click_time"), visibility("default")));

#endif
#endif
#if IN_HEADER(__GDK_DISPLAY_MANAGER_H__)
#if IN_FILE(__GDK_DISPLAY_MANAGER_C__)
#undef gdk_display_manager_get 
extern __typeof (gdk_display_manager_get) gdk_display_manager_get __attribute((alias("IA__gdk_display_manager_get"), visibility("default")));

#undef gdk_display_manager_get_type 
extern __typeof (gdk_display_manager_get_type) gdk_display_manager_get_type __attribute((alias("IA__gdk_display_manager_get_type"), visibility("default")));

#undef gdk_display_manager_list_displays 
extern __typeof (gdk_display_manager_list_displays) gdk_display_manager_list_displays __attribute((alias("IA__gdk_display_manager_list_displays"), visibility("default")));

#undef gdk_display_manager_set_default_display 
extern __typeof (gdk_display_manager_set_default_display) gdk_display_manager_set_default_display __attribute((alias("IA__gdk_display_manager_set_default_display"), visibility("default")));

#undef gdk_display_manager_get_default_display 
extern __typeof (gdk_display_manager_get_default_display) gdk_display_manager_get_default_display __attribute((alias("IA__gdk_display_manager_get_default_display"), visibility("default")));

#endif
#endif
#if IN_HEADER(__GDK_DND_H__)
#if IN_FILE(__GDK_DND_X11_C__)
#undef gdk_drag_abort 
extern __typeof (gdk_drag_abort) gdk_drag_abort __attribute((alias("IA__gdk_drag_abort"), visibility("default")));

#undef gdk_drag_begin 
extern __typeof (gdk_drag_begin) gdk_drag_begin __attribute((alias("IA__gdk_drag_begin"), visibility("default")));

#undef gdk_drag_context_get_type 
extern __typeof (gdk_drag_context_get_type) gdk_drag_context_get_type __attribute((alias("IA__gdk_drag_context_get_type"), visibility("default")));

#ifndef GDK_DISABLE_DEPRECATED
#undef gdk_drag_context_new 
extern __typeof (gdk_drag_context_new) gdk_drag_context_new __attribute((alias("IA__gdk_drag_context_new"), visibility("default")));

#undef gdk_drag_context_ref 
extern __typeof (gdk_drag_context_ref) gdk_drag_context_ref __attribute((alias("IA__gdk_drag_context_ref"), visibility("default")));

#undef gdk_drag_context_unref 
extern __typeof (gdk_drag_context_unref) gdk_drag_context_unref __attribute((alias("IA__gdk_drag_context_unref"), visibility("default")));

#endif
#undef gdk_drag_drop 
extern __typeof (gdk_drag_drop) gdk_drag_drop __attribute((alias("IA__gdk_drag_drop"), visibility("default")));

#undef gdk_drag_drop_succeeded 
extern __typeof (gdk_drag_drop_succeeded) gdk_drag_drop_succeeded __attribute((alias("IA__gdk_drag_drop_succeeded"), visibility("default")));

#undef gdk_drag_find_window_for_screen 
extern __typeof (gdk_drag_find_window_for_screen) gdk_drag_find_window_for_screen __attribute((alias("IA__gdk_drag_find_window_for_screen"), visibility("default")));

#undef gdk_drag_get_protocol_for_display 
extern __typeof (gdk_drag_get_protocol_for_display) gdk_drag_get_protocol_for_display __attribute((alias("IA__gdk_drag_get_protocol_for_display"), visibility("default")));

#undef gdk_drag_get_selection 
extern __typeof (gdk_drag_get_selection) gdk_drag_get_selection __attribute((alias("IA__gdk_drag_get_selection"), visibility("default")));

#undef gdk_drag_motion 
extern __typeof (gdk_drag_motion) gdk_drag_motion __attribute((alias("IA__gdk_drag_motion"), visibility("default")));

#undef gdk_drag_status 
extern __typeof (gdk_drag_status) gdk_drag_status __attribute((alias("IA__gdk_drag_status"), visibility("default")));

#undef gdk_drop_finish 
extern __typeof (gdk_drop_finish) gdk_drop_finish __attribute((alias("IA__gdk_drop_finish"), visibility("default")));

#undef gdk_drop_reply 
extern __typeof (gdk_drop_reply) gdk_drop_reply __attribute((alias("IA__gdk_drop_reply"), visibility("default")));

#endif
#endif
#if IN_HEADER(__GDK_DND_H__)
#if IN_FILE(__GDK_DND_C__)
#undef gdk_drag_context_get_actions 
extern __typeof (gdk_drag_context_get_actions) gdk_drag_context_get_actions __attribute((alias("IA__gdk_drag_context_get_actions"), visibility("default")));

#undef gdk_drag_context_get_selected_action 
extern __typeof (gdk_drag_context_get_selected_action) gdk_drag_context_get_selected_action __attribute((alias("IA__gdk_drag_context_get_selected_action"), visibility("default")));

#undef gdk_drag_context_get_suggested_action 
extern __typeof (gdk_drag_context_get_suggested_action) gdk_drag_context_get_suggested_action __attribute((alias("IA__gdk_drag_context_get_suggested_action"), visibility("default")));

#undef gdk_drag_context_list_targets 
extern __typeof (gdk_drag_context_list_targets) gdk_drag_context_list_targets __attribute((alias("IA__gdk_drag_context_list_targets"), visibility("default")));

#undef gdk_drag_context_get_source_window 
extern __typeof (gdk_drag_context_get_source_window) gdk_drag_context_get_source_window __attribute((alias("IA__gdk_drag_context_get_source_window"), visibility("default")));

#undef gdk_drag_context_get_dest_window 
extern __typeof (gdk_drag_context_get_dest_window) gdk_drag_context_get_dest_window __attribute((alias("IA__gdk_drag_context_get_dest_window"), visibility("default")));

#undef gdk_drag_context_get_protocol 
extern __typeof (gdk_drag_context_get_protocol) gdk_drag_context_get_protocol __attribute((alias("IA__gdk_drag_context_get_protocol"), visibility("default")));

#ifndef GDK_DISABLE_DEPRECATED
#undef gdk_drag_find_window 
extern __typeof (gdk_drag_find_window) gdk_drag_find_window __attribute((alias("IA__gdk_drag_find_window"), visibility("default")));

#undef gdk_drag_get_protocol 
extern __typeof (gdk_drag_get_protocol) gdk_drag_get_protocol __attribute((alias("IA__gdk_drag_get_protocol"), visibility("default")));

#endif
#endif
#endif
#if IN_HEADER(__GDK_DRAWABLE_H__)
#if IN_FILE(__GDK_DRAW_C__)
#undef gdk_drawable_copy_to_image 
extern __typeof (gdk_drawable_copy_to_image) gdk_drawable_copy_to_image __attribute((alias("IA__gdk_drawable_copy_to_image"), visibility("default")));

#undef gdk_drawable_get_clip_region 
extern __typeof (gdk_drawable_get_clip_region) gdk_drawable_get_clip_region __attribute((alias("IA__gdk_drawable_get_clip_region"), visibility("default")));

#undef gdk_drawable_get_colormap 
extern __typeof (gdk_drawable_get_colormap) gdk_drawable_get_colormap __attribute((alias("IA__gdk_drawable_get_colormap"), visibility("default")));

#ifndef GDK_DISABLE_DEPRECATED
#undef gdk_drawable_get_data 
extern __typeof (gdk_drawable_get_data) gdk_drawable_get_data __attribute((alias("IA__gdk_drawable_get_data"), visibility("default")));

#undef gdk_drawable_set_data 
extern __typeof (gdk_drawable_set_data) gdk_drawable_set_data __attribute((alias("IA__gdk_drawable_set_data"), visibility("default")));

#undef gdk_drawable_ref 
extern __typeof (gdk_drawable_ref) gdk_drawable_ref __attribute((alias("IA__gdk_drawable_ref"), visibility("default")));

#undef gdk_drawable_unref 
extern __typeof (gdk_drawable_unref) gdk_drawable_unref __attribute((alias("IA__gdk_drawable_unref"), visibility("default")));

#undef gdk_draw_string 
extern __typeof (gdk_draw_string) gdk_draw_string __attribute((alias("IA__gdk_draw_string"), visibility("default")));

#undef gdk_draw_text 
extern __typeof (gdk_draw_text) gdk_draw_text __attribute((alias("IA__gdk_draw_text"), visibility("default")));

#undef gdk_draw_text_wc 
extern __typeof (gdk_draw_text_wc) gdk_draw_text_wc __attribute((alias("IA__gdk_draw_text_wc"), visibility("default")));

#undef gdk_drawable_get_display 
extern __typeof (gdk_drawable_get_display) gdk_drawable_get_display __attribute((alias("IA__gdk_drawable_get_display"), visibility("default")));

#undef gdk_drawable_get_screen 
extern __typeof (gdk_drawable_get_screen) gdk_drawable_get_screen __attribute((alias("IA__gdk_drawable_get_screen"), visibility("default")));

#undef gdk_drawable_get_size 
extern __typeof (gdk_drawable_get_size) gdk_drawable_get_size __attribute((alias("IA__gdk_drawable_get_size"), visibility("default")));

#undef gdk_drawable_get_visual 
extern __typeof (gdk_drawable_get_visual) gdk_drawable_get_visual __attribute((alias("IA__gdk_drawable_get_visual"), visibility("default")));

#endif
#undef gdk_drawable_get_depth 
extern __typeof (gdk_drawable_get_depth) gdk_drawable_get_depth __attribute((alias("IA__gdk_drawable_get_depth"), visibility("default")));

#undef gdk_drawable_get_image 
extern __typeof (gdk_drawable_get_image) gdk_drawable_get_image __attribute((alias("IA__gdk_drawable_get_image"), visibility("default")));

#undef gdk_drawable_get_type 
extern __typeof (gdk_drawable_get_type) gdk_drawable_get_type __attribute((alias("IA__gdk_drawable_get_type"), visibility("default")));

#undef gdk_drawable_get_visible_region 
extern __typeof (gdk_drawable_get_visible_region) gdk_drawable_get_visible_region __attribute((alias("IA__gdk_drawable_get_visible_region"), visibility("default")));

#undef gdk_drawable_set_colormap 
extern __typeof (gdk_drawable_set_colormap) gdk_drawable_set_colormap __attribute((alias("IA__gdk_drawable_set_colormap"), visibility("default")));

#undef gdk_draw_arc 
extern __typeof (gdk_draw_arc) gdk_draw_arc __attribute((alias("IA__gdk_draw_arc"), visibility("default")));

#undef gdk_draw_drawable 
extern __typeof (gdk_draw_drawable) gdk_draw_drawable __attribute((alias("IA__gdk_draw_drawable"), visibility("default")));

#undef gdk_draw_glyphs 
extern __typeof (gdk_draw_glyphs) gdk_draw_glyphs __attribute((alias("IA__gdk_draw_glyphs"), visibility("default")));

#undef gdk_draw_glyphs_transformed 
extern __typeof (gdk_draw_glyphs_transformed) gdk_draw_glyphs_transformed __attribute((alias("IA__gdk_draw_glyphs_transformed"), visibility("default")));

#undef gdk_draw_image 
extern __typeof (gdk_draw_image) gdk_draw_image __attribute((alias("IA__gdk_draw_image"), visibility("default")));

#undef gdk_draw_line 
extern __typeof (gdk_draw_line) gdk_draw_line __attribute((alias("IA__gdk_draw_line"), visibility("default")));

#undef gdk_draw_lines 
extern __typeof (gdk_draw_lines) gdk_draw_lines __attribute((alias("IA__gdk_draw_lines"), visibility("default")));

#undef gdk_draw_pixbuf 
extern __typeof (gdk_draw_pixbuf) gdk_draw_pixbuf __attribute((alias("IA__gdk_draw_pixbuf"), visibility("default")));

#undef gdk_draw_point 
extern __typeof (gdk_draw_point) gdk_draw_point __attribute((alias("IA__gdk_draw_point"), visibility("default")));

#undef gdk_draw_points 
extern __typeof (gdk_draw_points) gdk_draw_points __attribute((alias("IA__gdk_draw_points"), visibility("default")));

#undef gdk_draw_polygon 
extern __typeof (gdk_draw_polygon) gdk_draw_polygon __attribute((alias("IA__gdk_draw_polygon"), visibility("default")));

#undef gdk_draw_rectangle 
extern __typeof (gdk_draw_rectangle) gdk_draw_rectangle __attribute((alias("IA__gdk_draw_rectangle"), visibility("default")));

#undef gdk_draw_segments 
extern __typeof (gdk_draw_segments) gdk_draw_segments __attribute((alias("IA__gdk_draw_segments"), visibility("default")));

#undef gdk_draw_trapezoids 
extern __typeof (gdk_draw_trapezoids) gdk_draw_trapezoids __attribute((alias("IA__gdk_draw_trapezoids"), visibility("default")));

#endif
#endif
#if IN_HEADER(__GDK_DRAWABLE_H__)
#if IN_FILE(__GDK_PANGO_C__)
#undef gdk_draw_layout 
extern __typeof (gdk_draw_layout) gdk_draw_layout __attribute((alias("IA__gdk_draw_layout"), visibility("default")));

#undef gdk_draw_layout_line 
extern __typeof (gdk_draw_layout_line) gdk_draw_layout_line __attribute((alias("IA__gdk_draw_layout_line"), visibility("default")));

#undef gdk_draw_layout_line_with_colors 
extern __typeof (gdk_draw_layout_line_with_colors) gdk_draw_layout_line_with_colors __attribute((alias("IA__gdk_draw_layout_line_with_colors"), visibility("default")));

#undef gdk_draw_layout_with_colors 
extern __typeof (gdk_draw_layout_with_colors) gdk_draw_layout_with_colors __attribute((alias("IA__gdk_draw_layout_with_colors"), visibility("default")));

#endif
#endif
#if IN_HEADER(__GDK_GC_H__)
#if IN_FILE(__GDK_GC_C__)
#undef gdk_gc_new 
extern __typeof (gdk_gc_new) gdk_gc_new __attribute((alias("IA__gdk_gc_new"), visibility("default")));

#undef gdk_gc_get_type 
extern __typeof (gdk_gc_get_type) gdk_gc_get_type __attribute((alias("IA__gdk_gc_get_type"), visibility("default")));

#undef gdk_gc_new_with_values 
extern __typeof (gdk_gc_new_with_values) gdk_gc_new_with_values __attribute((alias("IA__gdk_gc_new_with_values"), visibility("default")));

#ifndef GDK_DISABLE_DEPRECATED
#undef gdk_gc_ref 
extern __typeof (gdk_gc_ref) gdk_gc_ref __attribute((alias("IA__gdk_gc_ref"), visibility("default")));

#undef gdk_gc_unref 
extern __typeof (gdk_gc_unref) gdk_gc_unref __attribute((alias("IA__gdk_gc_unref"), visibility("default")));

#undef gdk_gc_set_font 
extern __typeof (gdk_gc_set_font) gdk_gc_set_font __attribute((alias("IA__gdk_gc_set_font"), visibility("default")));

#endif
#undef gdk_gc_get_values 
extern __typeof (gdk_gc_get_values) gdk_gc_get_values __attribute((alias("IA__gdk_gc_get_values"), visibility("default")));

#undef gdk_gc_set_values 
extern __typeof (gdk_gc_set_values) gdk_gc_set_values __attribute((alias("IA__gdk_gc_set_values"), visibility("default")));

#undef gdk_gc_set_foreground 
extern __typeof (gdk_gc_set_foreground) gdk_gc_set_foreground __attribute((alias("IA__gdk_gc_set_foreground"), visibility("default")));

#undef gdk_gc_set_background 
extern __typeof (gdk_gc_set_background) gdk_gc_set_background __attribute((alias("IA__gdk_gc_set_background"), visibility("default")));

#undef gdk_gc_set_function 
extern __typeof (gdk_gc_set_function) gdk_gc_set_function __attribute((alias("IA__gdk_gc_set_function"), visibility("default")));

#undef gdk_gc_set_fill 
extern __typeof (gdk_gc_set_fill) gdk_gc_set_fill __attribute((alias("IA__gdk_gc_set_fill"), visibility("default")));

#undef gdk_gc_set_tile 
extern __typeof (gdk_gc_set_tile) gdk_gc_set_tile __attribute((alias("IA__gdk_gc_set_tile"), visibility("default")));

#undef gdk_gc_set_stipple 
extern __typeof (gdk_gc_set_stipple) gdk_gc_set_stipple __attribute((alias("IA__gdk_gc_set_stipple"), visibility("default")));

#undef gdk_gc_set_ts_origin 
extern __typeof (gdk_gc_set_ts_origin) gdk_gc_set_ts_origin __attribute((alias("IA__gdk_gc_set_ts_origin"), visibility("default")));

#undef gdk_gc_set_clip_origin 
extern __typeof (gdk_gc_set_clip_origin) gdk_gc_set_clip_origin __attribute((alias("IA__gdk_gc_set_clip_origin"), visibility("default")));

#undef gdk_gc_set_clip_mask 
extern __typeof (gdk_gc_set_clip_mask) gdk_gc_set_clip_mask __attribute((alias("IA__gdk_gc_set_clip_mask"), visibility("default")));

#undef gdk_gc_set_clip_rectangle 
extern __typeof (gdk_gc_set_clip_rectangle) gdk_gc_set_clip_rectangle __attribute((alias("IA__gdk_gc_set_clip_rectangle"), visibility("default")));

#undef gdk_gc_set_clip_region 
extern __typeof (gdk_gc_set_clip_region) gdk_gc_set_clip_region __attribute((alias("IA__gdk_gc_set_clip_region"), visibility("default")));

#undef gdk_gc_set_subwindow 
extern __typeof (gdk_gc_set_subwindow) gdk_gc_set_subwindow __attribute((alias("IA__gdk_gc_set_subwindow"), visibility("default")));

#undef gdk_gc_set_exposures 
extern __typeof (gdk_gc_set_exposures) gdk_gc_set_exposures __attribute((alias("IA__gdk_gc_set_exposures"), visibility("default")));

#undef gdk_gc_set_line_attributes 
extern __typeof (gdk_gc_set_line_attributes) gdk_gc_set_line_attributes __attribute((alias("IA__gdk_gc_set_line_attributes"), visibility("default")));

#undef gdk_gc_set_dashes 
extern __typeof (gdk_gc_set_dashes) gdk_gc_set_dashes __attribute((alias("IA__gdk_gc_set_dashes"), visibility("default")));

#undef gdk_gc_offset 
extern __typeof (gdk_gc_offset) gdk_gc_offset __attribute((alias("IA__gdk_gc_offset"), visibility("default")));

#undef gdk_gc_copy 
extern __typeof (gdk_gc_copy) gdk_gc_copy __attribute((alias("IA__gdk_gc_copy"), visibility("default")));

#undef gdk_gc_get_colormap 
extern __typeof (gdk_gc_get_colormap) gdk_gc_get_colormap __attribute((alias("IA__gdk_gc_get_colormap"), visibility("default")));

#undef gdk_gc_set_colormap 
extern __typeof (gdk_gc_set_colormap) gdk_gc_set_colormap __attribute((alias("IA__gdk_gc_set_colormap"), visibility("default")));

#undef gdk_gc_set_rgb_bg_color 
extern __typeof (gdk_gc_set_rgb_bg_color) gdk_gc_set_rgb_bg_color __attribute((alias("IA__gdk_gc_set_rgb_bg_color"), visibility("default")));

#undef gdk_gc_set_rgb_fg_color 
extern __typeof (gdk_gc_set_rgb_fg_color) gdk_gc_set_rgb_fg_color __attribute((alias("IA__gdk_gc_set_rgb_fg_color"), visibility("default")));

#endif
#endif
#if IN_HEADER(__GDK_GC_H__)
#if IN_FILE(__GDK_GC_X11_C__)
#undef gdk_gc_get_screen 
extern __typeof (gdk_gc_get_screen) gdk_gc_get_screen __attribute((alias("IA__gdk_gc_get_screen"), visibility("default")));

#endif
#endif
#if IN_HEADER(__GDK_PIXMAP_X11_H__)
#if IN_FILE(__GDK_PIXMAP_X11_C__)
#ifdef GDK_WINDOWING_X11
#undef gdk_pixmap_impl_x11_get_type 
extern __typeof (gdk_pixmap_impl_x11_get_type) gdk_pixmap_impl_x11_get_type __attribute((alias("IA__gdk_pixmap_impl_x11_get_type"), visibility("default")));

#endif
#endif
#endif
#if IN_HEADER(__GDK_WINDOW_X11_H__)
#if IN_FILE(__GDK_WINDOW_X11_C__)
#ifdef GDK_WINDOWING_X11
#undef gdk_window_impl_x11_get_type 
extern __typeof (gdk_window_impl_x11_get_type) gdk_window_impl_x11_get_type __attribute((alias("IA__gdk_window_impl_x11_get_type"), visibility("default")));

#endif
#endif
#endif
#if IN_HEADER(__GDK_WINDOW_H__)
#if IN_FILE(__GDK_WINDOW_C__)
#undef gdk_get_default_root_window 
extern __typeof (gdk_get_default_root_window) gdk_get_default_root_window __attribute((alias("IA__gdk_get_default_root_window"), visibility("default")));

#undef gdk_window_new 
extern __typeof (gdk_window_new) gdk_window_new __attribute((alias("IA__gdk_window_new"), visibility("default")));

#undef gdk_window_show_unraised 
extern __typeof (gdk_window_show_unraised) gdk_window_show_unraised __attribute((alias("IA__gdk_window_show_unraised"), visibility("default")));

#undef gdk_window_show 
extern __typeof (gdk_window_show) gdk_window_show __attribute((alias("IA__gdk_window_show"), visibility("default")));

#undef gdk_window_hide 
extern __typeof (gdk_window_hide) gdk_window_hide __attribute((alias("IA__gdk_window_hide"), visibility("default")));

#undef gdk_window_withdraw 
extern __typeof (gdk_window_withdraw) gdk_window_withdraw __attribute((alias("IA__gdk_window_withdraw"), visibility("default")));

#undef gdk_window_get_events 
extern __typeof (gdk_window_get_events) gdk_window_get_events __attribute((alias("IA__gdk_window_get_events"), visibility("default")));

#undef gdk_window_set_events 
extern __typeof (gdk_window_set_events) gdk_window_set_events __attribute((alias("IA__gdk_window_set_events"), visibility("default")));

#undef gdk_window_raise 
extern __typeof (gdk_window_raise) gdk_window_raise __attribute((alias("IA__gdk_window_raise"), visibility("default")));

#undef gdk_window_lower 
extern __typeof (gdk_window_lower) gdk_window_lower __attribute((alias("IA__gdk_window_lower"), visibility("default")));

#undef gdk_window_restack 
extern __typeof (gdk_window_restack) gdk_window_restack __attribute((alias("IA__gdk_window_restack"), visibility("default")));

#undef gdk_window_move 
extern __typeof (gdk_window_move) gdk_window_move __attribute((alias("IA__gdk_window_move"), visibility("default")));

#undef gdk_window_resize 
extern __typeof (gdk_window_resize) gdk_window_resize __attribute((alias("IA__gdk_window_resize"), visibility("default")));

#undef gdk_window_move_resize 
extern __typeof (gdk_window_move_resize) gdk_window_move_resize __attribute((alias("IA__gdk_window_move_resize"), visibility("default")));

#undef gdk_window_scroll 
extern __typeof (gdk_window_scroll) gdk_window_scroll __attribute((alias("IA__gdk_window_scroll"), visibility("default")));

#undef gdk_window_move_region 
extern __typeof (gdk_window_move_region) gdk_window_move_region __attribute((alias("IA__gdk_window_move_region"), visibility("default")));

#undef gdk_window_get_accept_focus 
extern __typeof (gdk_window_get_accept_focus) gdk_window_get_accept_focus __attribute((alias("IA__gdk_window_get_accept_focus"), visibility("default")));

#undef gdk_window_get_background_pattern 
extern __typeof (gdk_window_get_background_pattern) gdk_window_get_background_pattern __attribute((alias("IA__gdk_window_get_background_pattern"), visibility("default")));

#undef gdk_window_get_composited 
extern __typeof (gdk_window_get_composited) gdk_window_get_composited __attribute((alias("IA__gdk_window_get_composited"), visibility("default")));

#undef gdk_window_get_cursor 
extern __typeof (gdk_window_get_cursor) gdk_window_get_cursor __attribute((alias("IA__gdk_window_get_cursor"), visibility("default")));

#undef gdk_window_get_deskrelative_origin 
extern __typeof (gdk_window_get_deskrelative_origin) gdk_window_get_deskrelative_origin __attribute((alias("IA__gdk_window_get_deskrelative_origin"), visibility("default")));

#undef gdk_window_get_focus_on_map 
extern __typeof (gdk_window_get_focus_on_map) gdk_window_get_focus_on_map __attribute((alias("IA__gdk_window_get_focus_on_map"), visibility("default")));

#undef gdk_window_get_geometry 
extern __typeof (gdk_window_get_geometry) gdk_window_get_geometry __attribute((alias("IA__gdk_window_get_geometry"), visibility("default")));

#undef gdk_window_get_modal_hint 
extern __typeof (gdk_window_get_modal_hint) gdk_window_get_modal_hint __attribute((alias("IA__gdk_window_get_modal_hint"), visibility("default")));

#undef gdk_window_get_origin 
extern __typeof (gdk_window_get_origin) gdk_window_get_origin __attribute((alias("IA__gdk_window_get_origin"), visibility("default")));

#undef gdk_window_get_root_coords 
extern __typeof (gdk_window_get_root_coords) gdk_window_get_root_coords __attribute((alias("IA__gdk_window_get_root_coords"), visibility("default")));

#undef gdk_window_set_background 
extern __typeof (gdk_window_set_background) gdk_window_set_background __attribute((alias("IA__gdk_window_set_background"), visibility("default")));

#undef gdk_window_set_back_pixmap 
extern __typeof (gdk_window_set_back_pixmap) gdk_window_set_back_pixmap __attribute((alias("IA__gdk_window_set_back_pixmap"), visibility("default")));

#undef gdk_window_set_cursor 
extern __typeof (gdk_window_set_cursor) gdk_window_set_cursor __attribute((alias("IA__gdk_window_set_cursor"), visibility("default")));

#undef gdk_window_shape_combine_mask 
extern __typeof (gdk_window_shape_combine_mask) gdk_window_shape_combine_mask __attribute((alias("IA__gdk_window_shape_combine_mask"), visibility("default")));

#undef gdk_window_shape_combine_region 
extern __typeof (gdk_window_shape_combine_region) gdk_window_shape_combine_region __attribute((alias("IA__gdk_window_shape_combine_region"), visibility("default")));

#undef gdk_window_set_child_shapes 
extern __typeof (gdk_window_set_child_shapes) gdk_window_set_child_shapes __attribute((alias("IA__gdk_window_set_child_shapes"), visibility("default")));

#undef gdk_window_merge_child_shapes 
extern __typeof (gdk_window_merge_child_shapes) gdk_window_merge_child_shapes __attribute((alias("IA__gdk_window_merge_child_shapes"), visibility("default")));

#undef gdk_window_input_shape_combine_mask 
extern __typeof (gdk_window_input_shape_combine_mask) gdk_window_input_shape_combine_mask __attribute((alias("IA__gdk_window_input_shape_combine_mask"), visibility("default")));

#undef gdk_window_input_shape_combine_region 
extern __typeof (gdk_window_input_shape_combine_region) gdk_window_input_shape_combine_region __attribute((alias("IA__gdk_window_input_shape_combine_region"), visibility("default")));

#undef gdk_window_set_child_input_shapes 
extern __typeof (gdk_window_set_child_input_shapes) gdk_window_set_child_input_shapes __attribute((alias("IA__gdk_window_set_child_input_shapes"), visibility("default")));

#undef gdk_window_merge_child_input_shapes 
extern __typeof (gdk_window_merge_child_input_shapes) gdk_window_merge_child_input_shapes __attribute((alias("IA__gdk_window_merge_child_input_shapes"), visibility("default")));

#undef gdk_window_set_static_gravities 
extern __typeof (gdk_window_set_static_gravities) gdk_window_set_static_gravities __attribute((alias("IA__gdk_window_set_static_gravities"), visibility("default")));

#undef gdk_window_reparent 
extern __typeof (gdk_window_reparent) gdk_window_reparent __attribute((alias("IA__gdk_window_reparent"), visibility("default")));

#undef gdk_window_add_filter 
extern __typeof (gdk_window_add_filter) gdk_window_add_filter __attribute((alias("IA__gdk_window_add_filter"), visibility("default")));

#undef gdk_window_at_pointer 
extern __typeof (gdk_window_at_pointer) gdk_window_at_pointer __attribute((alias("IA__gdk_window_at_pointer"), visibility("default")));

#undef gdk_window_begin_paint_rect 
extern __typeof (gdk_window_begin_paint_rect) gdk_window_begin_paint_rect __attribute((alias("IA__gdk_window_begin_paint_rect"), visibility("default")));

#undef gdk_window_begin_paint_region 
extern __typeof (gdk_window_begin_paint_region) gdk_window_begin_paint_region __attribute((alias("IA__gdk_window_begin_paint_region"), visibility("default")));

#undef gdk_window_clear 
extern __typeof (gdk_window_clear) gdk_window_clear __attribute((alias("IA__gdk_window_clear"), visibility("default")));

#undef gdk_window_clear_area 
extern __typeof (gdk_window_clear_area) gdk_window_clear_area __attribute((alias("IA__gdk_window_clear_area"), visibility("default")));

#undef gdk_window_clear_area_e 
extern __typeof (gdk_window_clear_area_e) gdk_window_clear_area_e __attribute((alias("IA__gdk_window_clear_area_e"), visibility("default")));

#undef gdk_window_constrain_size 
extern __typeof (gdk_window_constrain_size) gdk_window_constrain_size __attribute((alias("IA__gdk_window_constrain_size"), visibility("default")));

#undef gdk_window_coords_from_parent 
extern __typeof (gdk_window_coords_from_parent) gdk_window_coords_from_parent __attribute((alias("IA__gdk_window_coords_from_parent"), visibility("default")));

#undef gdk_window_coords_to_parent 
extern __typeof (gdk_window_coords_to_parent) gdk_window_coords_to_parent __attribute((alias("IA__gdk_window_coords_to_parent"), visibility("default")));

#undef gdk_window_create_similar_surface 
extern __typeof (gdk_window_create_similar_surface) gdk_window_create_similar_surface __attribute((alias("IA__gdk_window_create_similar_surface"), visibility("default")));

#undef gdk_window_destroy 
extern __typeof (gdk_window_destroy) gdk_window_destroy __attribute((alias("IA__gdk_window_destroy"), visibility("default")));

#undef gdk_window_end_paint 
extern __typeof (gdk_window_end_paint) gdk_window_end_paint __attribute((alias("IA__gdk_window_end_paint"), visibility("default")));

#undef gdk_window_flush 
extern __typeof (gdk_window_flush) gdk_window_flush __attribute((alias("IA__gdk_window_flush"), visibility("default")));

#undef gdk_window_foreign_new 
extern __typeof (gdk_window_foreign_new) gdk_window_foreign_new __attribute((alias("IA__gdk_window_foreign_new"), visibility("default")));

#undef gdk_window_freeze_toplevel_updates_libgtk_only 
extern __typeof (gdk_window_freeze_toplevel_updates_libgtk_only) gdk_window_freeze_toplevel_updates_libgtk_only __attribute((alias("IA__gdk_window_freeze_toplevel_updates_libgtk_only"), visibility("default")));

#undef gdk_window_freeze_updates 
extern __typeof (gdk_window_freeze_updates) gdk_window_freeze_updates __attribute((alias("IA__gdk_window_freeze_updates"), visibility("default")));

#undef gdk_window_get_children 
extern __typeof (gdk_window_get_children) gdk_window_get_children __attribute((alias("IA__gdk_window_get_children"), visibility("default")));

#undef gdk_window_get_internal_paint_info 
extern __typeof (gdk_window_get_internal_paint_info) gdk_window_get_internal_paint_info __attribute((alias("IA__gdk_window_get_internal_paint_info"), visibility("default")));

#undef gdk_window_get_parent 
extern __typeof (gdk_window_get_parent) gdk_window_get_parent __attribute((alias("IA__gdk_window_get_parent"), visibility("default")));

#undef gdk_window_get_effective_parent 
extern __typeof (gdk_window_get_effective_parent) gdk_window_get_effective_parent __attribute((alias("IA__gdk_window_get_effective_parent"), visibility("default")));

#undef gdk_window_get_pointer 
extern __typeof (gdk_window_get_pointer) gdk_window_get_pointer __attribute((alias("IA__gdk_window_get_pointer"), visibility("default")));

#undef gdk_window_get_position 
extern __typeof (gdk_window_get_position) gdk_window_get_position __attribute((alias("IA__gdk_window_get_position"), visibility("default")));

#undef gdk_window_get_state 
extern __typeof (gdk_window_get_state) gdk_window_get_state __attribute((alias("IA__gdk_window_get_state"), visibility("default")));

#undef gdk_window_get_toplevel 
extern __typeof (gdk_window_get_toplevel) gdk_window_get_toplevel __attribute((alias("IA__gdk_window_get_toplevel"), visibility("default")));

#undef gdk_window_get_effective_toplevel 
extern __typeof (gdk_window_get_effective_toplevel) gdk_window_get_effective_toplevel __attribute((alias("IA__gdk_window_get_effective_toplevel"), visibility("default")));

#ifndef GDK_DISABLE_DEPRECATED
#undef gdk_window_get_toplevels 
extern __typeof (gdk_window_get_toplevels) gdk_window_get_toplevels __attribute((alias("IA__gdk_window_get_toplevels"), visibility("default")));

#endif
#undef gdk_window_get_update_area 
extern __typeof (gdk_window_get_update_area) gdk_window_get_update_area __attribute((alias("IA__gdk_window_get_update_area"), visibility("default")));

#undef gdk_window_get_user_data 
extern __typeof (gdk_window_get_user_data) gdk_window_get_user_data __attribute((alias("IA__gdk_window_get_user_data"), visibility("default")));

#undef gdk_window_get_window_type 
extern __typeof (gdk_window_get_window_type) gdk_window_get_window_type __attribute((alias("IA__gdk_window_get_window_type"), visibility("default")));

#undef gdk_window_has_native 
extern __typeof (gdk_window_has_native) gdk_window_has_native __attribute((alias("IA__gdk_window_has_native"), visibility("default")));

#undef gdk_window_invalidate_maybe_recurse 
extern __typeof (gdk_window_invalidate_maybe_recurse) gdk_window_invalidate_maybe_recurse __attribute((alias("IA__gdk_window_invalidate_maybe_recurse"), visibility("default")));

#undef gdk_window_invalidate_rect 
extern __typeof (gdk_window_invalidate_rect) gdk_window_invalidate_rect __attribute((alias("IA__gdk_window_invalidate_rect"), visibility("default")));

#undef gdk_window_invalidate_region 
extern __typeof (gdk_window_invalidate_region) gdk_window_invalidate_region __attribute((alias("IA__gdk_window_invalidate_region"), visibility("default")));

#undef gdk_window_is_destroyed 
extern __typeof (gdk_window_is_destroyed) gdk_window_is_destroyed __attribute((alias("IA__gdk_window_is_destroyed"), visibility("default")));

#undef gdk_window_is_input_only 
extern __typeof (gdk_window_is_input_only) gdk_window_is_input_only __attribute((alias("IA__gdk_window_is_input_only"), visibility("default")));

#undef gdk_window_is_shaped 
extern __typeof (gdk_window_is_shaped) gdk_window_is_shaped __attribute((alias("IA__gdk_window_is_shaped"), visibility("default")));

#undef gdk_window_is_viewable 
extern __typeof (gdk_window_is_viewable) gdk_window_is_viewable __attribute((alias("IA__gdk_window_is_viewable"), visibility("default")));

#undef gdk_window_is_visible 
extern __typeof (gdk_window_is_visible) gdk_window_is_visible __attribute((alias("IA__gdk_window_is_visible"), visibility("default")));

#undef gdk_window_object_get_type 
extern __typeof (gdk_window_object_get_type) gdk_window_object_get_type __attribute((alias("IA__gdk_window_object_get_type"), visibility("default")));

#undef gdk_window_peek_children 
extern __typeof (gdk_window_peek_children) gdk_window_peek_children __attribute((alias("IA__gdk_window_peek_children"), visibility("default")));

#undef gdk_window_process_all_updates 
extern __typeof (gdk_window_process_all_updates) gdk_window_process_all_updates __attribute((alias("IA__gdk_window_process_all_updates"), visibility("default")));

#undef gdk_window_process_updates 
extern __typeof (gdk_window_process_updates) gdk_window_process_updates __attribute((alias("IA__gdk_window_process_updates"), visibility("default")));

#undef gdk_window_redirect_to_drawable 
extern __typeof (gdk_window_redirect_to_drawable) gdk_window_redirect_to_drawable __attribute((alias("IA__gdk_window_redirect_to_drawable"), visibility("default")));

#undef gdk_window_remove_filter 
extern __typeof (gdk_window_remove_filter) gdk_window_remove_filter __attribute((alias("IA__gdk_window_remove_filter"), visibility("default")));

#undef gdk_window_remove_redirection 
extern __typeof (gdk_window_remove_redirection) gdk_window_remove_redirection __attribute((alias("IA__gdk_window_remove_redirection"), visibility("default")));

#undef gdk_window_set_debug_updates 
extern __typeof (gdk_window_set_debug_updates) gdk_window_set_debug_updates __attribute((alias("IA__gdk_window_set_debug_updates"), visibility("default")));

#undef gdk_window_set_user_data 
extern __typeof (gdk_window_set_user_data) gdk_window_set_user_data __attribute((alias("IA__gdk_window_set_user_data"), visibility("default")));

#undef gdk_window_thaw_toplevel_updates_libgtk_only 
extern __typeof (gdk_window_thaw_toplevel_updates_libgtk_only) gdk_window_thaw_toplevel_updates_libgtk_only __attribute((alias("IA__gdk_window_thaw_toplevel_updates_libgtk_only"), visibility("default")));

#undef gdk_window_thaw_updates 
extern __typeof (gdk_window_thaw_updates) gdk_window_thaw_updates __attribute((alias("IA__gdk_window_thaw_updates"), visibility("default")));

#undef gdk_window_set_composited 
extern __typeof (gdk_window_set_composited) gdk_window_set_composited __attribute((alias("IA__gdk_window_set_composited"), visibility("default")));

#undef gdk_pointer_grab 
extern __typeof (gdk_pointer_grab) gdk_pointer_grab __attribute((alias("IA__gdk_pointer_grab"), visibility("default")));

#undef gdk_window_beep 
extern __typeof (gdk_window_beep) gdk_window_beep __attribute((alias("IA__gdk_window_beep"), visibility("default")));

#undef gdk_window_geometry_changed 
extern __typeof (gdk_window_geometry_changed) gdk_window_geometry_changed __attribute((alias("IA__gdk_window_geometry_changed"), visibility("default")));

#undef gdk_window_ensure_native 
extern __typeof (gdk_window_ensure_native) gdk_window_ensure_native __attribute((alias("IA__gdk_window_ensure_native"), visibility("default")));

#undef gdk_window_get_screen 
extern __typeof (gdk_window_get_screen) gdk_window_get_screen __attribute((alias("IA__gdk_window_get_screen"), visibility("default")));

#undef gdk_window_get_display 
extern __typeof (gdk_window_get_display) gdk_window_get_display __attribute((alias("IA__gdk_window_get_display"), visibility("default")));

#undef gdk_window_get_visual 
extern __typeof (gdk_window_get_visual) gdk_window_get_visual __attribute((alias("IA__gdk_window_get_visual"), visibility("default")));

#undef gdk_window_get_width 
extern __typeof (gdk_window_get_width) gdk_window_get_width __attribute((alias("IA__gdk_window_get_width"), visibility("default")));

#undef gdk_window_get_height 
extern __typeof (gdk_window_get_height) gdk_window_get_height __attribute((alias("IA__gdk_window_get_height"), visibility("default")));

#endif
#endif
#if IN_HEADER(__GDK_WINDOW_H__)
#if IN_FILE(__GDK_OFFSCREEN_WINDOW_C__)
#undef gdk_offscreen_window_get_pixmap 
extern __typeof (gdk_offscreen_window_get_pixmap) gdk_offscreen_window_get_pixmap __attribute((alias("IA__gdk_offscreen_window_get_pixmap"), visibility("default")));

#undef gdk_offscreen_window_set_embedder 
extern __typeof (gdk_offscreen_window_set_embedder) gdk_offscreen_window_set_embedder __attribute((alias("IA__gdk_offscreen_window_set_embedder"), visibility("default")));

#undef gdk_offscreen_window_get_embedder 
extern __typeof (gdk_offscreen_window_get_embedder) gdk_offscreen_window_get_embedder __attribute((alias("IA__gdk_offscreen_window_get_embedder"), visibility("default")));

#endif
#endif
#if IN_HEADER(__GDK_INTERNALS_H__)
#if IN_FILE(__GDK_OFFSCREEN_WINDOW_C__)
#undef gdk_offscreen_window_get_type 
extern __typeof (gdk_offscreen_window_get_type) gdk_offscreen_window_get_type __attribute((alias("IA__gdk_offscreen_window_get_type"), visibility("default")));

#endif
#endif
#if IN_HEADER(__GDK_WINDOW_H__)
#if IN_FILE(__GDK_DND_X11_C__)
#undef gdk_window_register_dnd 
extern __typeof (gdk_window_register_dnd) gdk_window_register_dnd __attribute((alias("IA__gdk_window_register_dnd"), visibility("default")));

#endif
#endif
#if IN_HEADER(__GDK_WINDOW_H__)
#if IN_FILE(__GDK_WINDOW_X11_C__)
#undef gdk_window_foreign_new_for_display 
extern __typeof (gdk_window_foreign_new_for_display) gdk_window_foreign_new_for_display __attribute((alias("IA__gdk_window_foreign_new_for_display"), visibility("default")));

#undef gdk_window_focus 
extern __typeof (gdk_window_focus) gdk_window_focus __attribute((alias("IA__gdk_window_focus"), visibility("default")));

#undef gdk_window_lookup 
extern __typeof (gdk_window_lookup) gdk_window_lookup __attribute((alias("IA__gdk_window_lookup"), visibility("default")));

#undef gdk_window_lookup_for_display 
extern __typeof (gdk_window_lookup_for_display) gdk_window_lookup_for_display __attribute((alias("IA__gdk_window_lookup_for_display"), visibility("default")));

#ifndef GDK_DISABLE_DEPRECATED
#undef gdk_window_set_hints 
extern __typeof (gdk_window_set_hints) gdk_window_set_hints __attribute((alias("IA__gdk_window_set_hints"), visibility("default")));

#endif
#undef gdk_window_get_type_hint 
extern __typeof (gdk_window_get_type_hint) gdk_window_get_type_hint __attribute((alias("IA__gdk_window_get_type_hint"), visibility("default")));

#undef gdk_window_set_type_hint 
extern __typeof (gdk_window_set_type_hint) gdk_window_set_type_hint __attribute((alias("IA__gdk_window_set_type_hint"), visibility("default")));

#undef gdk_window_set_modal_hint 
extern __typeof (gdk_window_set_modal_hint) gdk_window_set_modal_hint __attribute((alias("IA__gdk_window_set_modal_hint"), visibility("default")));

#undef gdk_window_set_skip_taskbar_hint 
extern __typeof (gdk_window_set_skip_taskbar_hint) gdk_window_set_skip_taskbar_hint __attribute((alias("IA__gdk_window_set_skip_taskbar_hint"), visibility("default")));

#undef gdk_window_set_skip_pager_hint 
extern __typeof (gdk_window_set_skip_pager_hint) gdk_window_set_skip_pager_hint __attribute((alias("IA__gdk_window_set_skip_pager_hint"), visibility("default")));

#undef gdk_window_set_urgency_hint 
extern __typeof (gdk_window_set_urgency_hint) gdk_window_set_urgency_hint __attribute((alias("IA__gdk_window_set_urgency_hint"), visibility("default")));

#undef gdk_window_set_geometry_hints 
extern __typeof (gdk_window_set_geometry_hints) gdk_window_set_geometry_hints __attribute((alias("IA__gdk_window_set_geometry_hints"), visibility("default")));

#undef gdk_window_set_title 
extern __typeof (gdk_window_set_title) gdk_window_set_title __attribute((alias("IA__gdk_window_set_title"), visibility("default")));

#undef gdk_window_set_role 
extern __typeof (gdk_window_set_role) gdk_window_set_role __attribute((alias("IA__gdk_window_set_role"), visibility("default")));

#undef gdk_window_set_startup_id 
extern __typeof (gdk_window_set_startup_id) gdk_window_set_startup_id __attribute((alias("IA__gdk_window_set_startup_id"), visibility("default")));

#undef gdk_window_set_transient_for 
extern __typeof (gdk_window_set_transient_for) gdk_window_set_transient_for __attribute((alias("IA__gdk_window_set_transient_for"), visibility("default")));

#undef gdk_window_get_root_origin 
extern __typeof (gdk_window_get_root_origin) gdk_window_get_root_origin __attribute((alias("IA__gdk_window_get_root_origin"), visibility("default")));

#undef gdk_window_get_frame_extents 
extern __typeof (gdk_window_get_frame_extents) gdk_window_get_frame_extents __attribute((alias("IA__gdk_window_get_frame_extents"), visibility("default")));

#undef gdk_window_set_override_redirect 
extern __typeof (gdk_window_set_override_redirect) gdk_window_set_override_redirect __attribute((alias("IA__gdk_window_set_override_redirect"), visibility("default")));

#undef gdk_window_set_accept_focus 
extern __typeof (gdk_window_set_accept_focus) gdk_window_set_accept_focus __attribute((alias("IA__gdk_window_set_accept_focus"), visibility("default")));

#undef gdk_window_set_focus_on_map 
extern __typeof (gdk_window_set_focus_on_map) gdk_window_set_focus_on_map __attribute((alias("IA__gdk_window_set_focus_on_map"), visibility("default")));

#undef gdk_window_set_icon_list 
extern __typeof (gdk_window_set_icon_list) gdk_window_set_icon_list __attribute((alias("IA__gdk_window_set_icon_list"), visibility("default")));

#undef gdk_window_set_icon 
extern __typeof (gdk_window_set_icon) gdk_window_set_icon __attribute((alias("IA__gdk_window_set_icon"), visibility("default")));

#undef gdk_window_set_icon_name 
extern __typeof (gdk_window_set_icon_name) gdk_window_set_icon_name __attribute((alias("IA__gdk_window_set_icon_name"), visibility("default")));

#undef gdk_window_set_opacity 
extern __typeof (gdk_window_set_opacity) gdk_window_set_opacity __attribute((alias("IA__gdk_window_set_opacity"), visibility("default")));

#undef gdk_window_iconify 
extern __typeof (gdk_window_iconify) gdk_window_iconify __attribute((alias("IA__gdk_window_iconify"), visibility("default")));

#undef gdk_window_deiconify 
extern __typeof (gdk_window_deiconify) gdk_window_deiconify __attribute((alias("IA__gdk_window_deiconify"), visibility("default")));

#undef gdk_window_stick 
extern __typeof (gdk_window_stick) gdk_window_stick __attribute((alias("IA__gdk_window_stick"), visibility("default")));

#undef gdk_window_unstick 
extern __typeof (gdk_window_unstick) gdk_window_unstick __attribute((alias("IA__gdk_window_unstick"), visibility("default")));

#undef gdk_window_maximize 
extern __typeof (gdk_window_maximize) gdk_window_maximize __attribute((alias("IA__gdk_window_maximize"), visibility("default")));

#undef gdk_window_unmaximize 
extern __typeof (gdk_window_unmaximize) gdk_window_unmaximize __attribute((alias("IA__gdk_window_unmaximize"), visibility("default")));

#undef gdk_window_fullscreen 
extern __typeof (gdk_window_fullscreen) gdk_window_fullscreen __attribute((alias("IA__gdk_window_fullscreen"), visibility("default")));

#undef gdk_window_unfullscreen 
extern __typeof (gdk_window_unfullscreen) gdk_window_unfullscreen __attribute((alias("IA__gdk_window_unfullscreen"), visibility("default")));

#undef gdk_window_set_keep_above 
extern __typeof (gdk_window_set_keep_above) gdk_window_set_keep_above __attribute((alias("IA__gdk_window_set_keep_above"), visibility("default")));

#undef gdk_window_set_keep_below 
extern __typeof (gdk_window_set_keep_below) gdk_window_set_keep_below __attribute((alias("IA__gdk_window_set_keep_below"), visibility("default")));

#undef gdk_window_get_group 
extern __typeof (gdk_window_get_group) gdk_window_get_group __attribute((alias("IA__gdk_window_get_group"), visibility("default")));

#undef gdk_window_set_group 
extern __typeof (gdk_window_set_group) gdk_window_set_group __attribute((alias("IA__gdk_window_set_group"), visibility("default")));

#undef gdk_window_get_decorations 
extern __typeof (gdk_window_get_decorations) gdk_window_get_decorations __attribute((alias("IA__gdk_window_get_decorations"), visibility("default")));

#undef gdk_window_set_decorations 
extern __typeof (gdk_window_set_decorations) gdk_window_set_decorations __attribute((alias("IA__gdk_window_set_decorations"), visibility("default")));

#undef gdk_window_set_functions 
extern __typeof (gdk_window_set_functions) gdk_window_set_functions __attribute((alias("IA__gdk_window_set_functions"), visibility("default")));

#undef gdk_window_begin_move_drag 
extern __typeof (gdk_window_begin_move_drag) gdk_window_begin_move_drag __attribute((alias("IA__gdk_window_begin_move_drag"), visibility("default")));

#undef gdk_window_begin_resize_drag 
extern __typeof (gdk_window_begin_resize_drag) gdk_window_begin_resize_drag __attribute((alias("IA__gdk_window_begin_resize_drag"), visibility("default")));

#undef gdk_window_enable_synchronized_configure 
extern __typeof (gdk_window_enable_synchronized_configure) gdk_window_enable_synchronized_configure __attribute((alias("IA__gdk_window_enable_synchronized_configure"), visibility("default")));

#undef gdk_window_configure_finished 
extern __typeof (gdk_window_configure_finished) gdk_window_configure_finished __attribute((alias("IA__gdk_window_configure_finished"), visibility("default")));

#endif
#endif
#if IN_HEADER(__GDK_IMAGE_H__)
#if IN_FILE(__GDK_IMAGE_C__)
#undef gdk_image_get_bits_per_pixel 
extern __typeof (gdk_image_get_bits_per_pixel) gdk_image_get_bits_per_pixel __attribute((alias("IA__gdk_image_get_bits_per_pixel"), visibility("default")));

#undef gdk_image_get_bytes_per_pixel 
extern __typeof (gdk_image_get_bytes_per_pixel) gdk_image_get_bytes_per_pixel __attribute((alias("IA__gdk_image_get_bytes_per_pixel"), visibility("default")));

#undef gdk_image_get_bytes_per_line 
extern __typeof (gdk_image_get_bytes_per_line) gdk_image_get_bytes_per_line __attribute((alias("IA__gdk_image_get_bytes_per_line"), visibility("default")));

#undef gdk_image_get_byte_order 
extern __typeof (gdk_image_get_byte_order) gdk_image_get_byte_order __attribute((alias("IA__gdk_image_get_byte_order"), visibility("default")));

#undef gdk_image_get_depth 
extern __typeof (gdk_image_get_depth) gdk_image_get_depth __attribute((alias("IA__gdk_image_get_depth"), visibility("default")));

#undef gdk_image_get_height 
extern __typeof (gdk_image_get_height) gdk_image_get_height __attribute((alias("IA__gdk_image_get_height"), visibility("default")));

#undef gdk_image_get_image_type 
extern __typeof (gdk_image_get_image_type) gdk_image_get_image_type __attribute((alias("IA__gdk_image_get_image_type"), visibility("default")));

#undef gdk_image_get_visual 
extern __typeof (gdk_image_get_visual) gdk_image_get_visual __attribute((alias("IA__gdk_image_get_visual"), visibility("default")));

#undef gdk_image_get_width 
extern __typeof (gdk_image_get_width) gdk_image_get_width __attribute((alias("IA__gdk_image_get_width"), visibility("default")));

#ifndef GDK_DISABLE_DEPRECATED
#undef gdk_image_ref 
extern __typeof (gdk_image_ref) gdk_image_ref __attribute((alias("IA__gdk_image_ref"), visibility("default")));

#undef gdk_image_unref 
extern __typeof (gdk_image_unref) gdk_image_unref __attribute((alias("IA__gdk_image_unref"), visibility("default")));

#undef gdk_image_get 
extern __typeof (gdk_image_get) gdk_image_get __attribute((alias("IA__gdk_image_get"), visibility("default")));

#endif
#undef gdk_image_get_pixels 
extern __typeof (gdk_image_get_pixels) gdk_image_get_pixels __attribute((alias("IA__gdk_image_get_pixels"), visibility("default")));

#undef gdk_image_set_colormap 
extern __typeof (gdk_image_set_colormap) gdk_image_set_colormap __attribute((alias("IA__gdk_image_set_colormap"), visibility("default")));

#undef gdk_image_get_colormap 
extern __typeof (gdk_image_get_colormap) gdk_image_get_colormap __attribute((alias("IA__gdk_image_get_colormap"), visibility("default")));

#undef gdk_image_new 
extern __typeof (gdk_image_new) gdk_image_new __attribute((alias("IA__gdk_image_new"), visibility("default")));

#endif
#endif
#if IN_HEADER(__GDK_IMAGE_H__)
#if IN_FILE(__GDK_IMAGE_X11_C__)
#ifdef GDK_ENABLE_BROKEN
#undef gdk_image_new_bitmap 
extern __typeof (gdk_image_new_bitmap) gdk_image_new_bitmap __attribute((alias("IA__gdk_image_new_bitmap"), visibility("default")));

#endif
#undef gdk_image_get_pixel 
extern __typeof (gdk_image_get_pixel) gdk_image_get_pixel __attribute((alias("IA__gdk_image_get_pixel"), visibility("default")));

#undef gdk_image_put_pixel 
extern __typeof (gdk_image_put_pixel) gdk_image_put_pixel __attribute((alias("IA__gdk_image_put_pixel"), visibility("default")));

#undef gdk_image_get_type 
extern __typeof (gdk_image_get_type) gdk_image_get_type __attribute((alias("IA__gdk_image_get_type"), visibility("default")));

#endif
#endif
#if IN_HEADER(__GDK_KEYS_H__)
#if IN_FILE(__GDK_KEYS_C__)
#undef gdk_keymap_get_default 
extern __typeof (gdk_keymap_get_default) gdk_keymap_get_default __attribute((alias("IA__gdk_keymap_get_default"), visibility("default")));

#undef gdk_keymap_get_type 
extern __typeof (gdk_keymap_get_type) gdk_keymap_get_type __attribute((alias("IA__gdk_keymap_get_type"), visibility("default")));

#undef gdk_keyval_is_lower 
extern __typeof (gdk_keyval_is_lower) gdk_keyval_is_lower __attribute((alias("IA__gdk_keyval_is_lower"), visibility("default")));

#undef gdk_keyval_is_upper 
extern __typeof (gdk_keyval_is_upper) gdk_keyval_is_upper __attribute((alias("IA__gdk_keyval_is_upper"), visibility("default")));

#undef gdk_keyval_to_lower 
extern __typeof (gdk_keyval_to_lower) gdk_keyval_to_lower __attribute((alias("IA__gdk_keyval_to_lower"), visibility("default")));

#undef gdk_keyval_to_upper 
extern __typeof (gdk_keyval_to_upper) gdk_keyval_to_upper __attribute((alias("IA__gdk_keyval_to_upper"), visibility("default")));

#endif
#endif
#if IN_HEADER(__GDK_KEYS_H__)
#if IN_FILE(__GDK_KEYUNI_C__)
#undef gdk_keyval_to_unicode 
extern __typeof (gdk_keyval_to_unicode) gdk_keyval_to_unicode __attribute((alias("IA__gdk_keyval_to_unicode"), visibility("default")));

#undef gdk_unicode_to_keyval 
extern __typeof (gdk_unicode_to_keyval) gdk_unicode_to_keyval __attribute((alias("IA__gdk_unicode_to_keyval"), visibility("default")));

#endif
#endif
#if IN_HEADER(__GDK_KEYS_H__)
#if IN_FILE(__GDK_KEYS_X11_C__)
#undef gdk_keymap_get_direction 
extern __typeof (gdk_keymap_get_direction) gdk_keymap_get_direction __attribute((alias("IA__gdk_keymap_get_direction"), visibility("default")));

#undef gdk_keymap_get_entries_for_keycode 
extern __typeof (gdk_keymap_get_entries_for_keycode) gdk_keymap_get_entries_for_keycode __attribute((alias("IA__gdk_keymap_get_entries_for_keycode"), visibility("default")));

#undef gdk_keymap_get_entries_for_keyval 
extern __typeof (gdk_keymap_get_entries_for_keyval) gdk_keymap_get_entries_for_keyval __attribute((alias("IA__gdk_keymap_get_entries_for_keyval"), visibility("default")));

#undef gdk_keymap_get_for_display 
extern __typeof (gdk_keymap_get_for_display) gdk_keymap_get_for_display __attribute((alias("IA__gdk_keymap_get_for_display"), visibility("default")));

#undef gdk_keymap_have_bidi_layouts 
extern __typeof (gdk_keymap_have_bidi_layouts) gdk_keymap_have_bidi_layouts __attribute((alias("IA__gdk_keymap_have_bidi_layouts"), visibility("default")));

#undef gdk_keymap_get_caps_lock_state 
extern __typeof (gdk_keymap_get_caps_lock_state) gdk_keymap_get_caps_lock_state __attribute((alias("IA__gdk_keymap_get_caps_lock_state"), visibility("default")));

#undef gdk_keymap_lookup_key 
extern __typeof (gdk_keymap_lookup_key) gdk_keymap_lookup_key __attribute((alias("IA__gdk_keymap_lookup_key"), visibility("default")));

#undef gdk_keymap_translate_keyboard_state 
extern __typeof (gdk_keymap_translate_keyboard_state) gdk_keymap_translate_keyboard_state __attribute((alias("IA__gdk_keymap_translate_keyboard_state"), visibility("default")));

#undef gdk_keymap_add_virtual_modifiers 
extern __typeof (gdk_keymap_add_virtual_modifiers) gdk_keymap_add_virtual_modifiers __attribute((alias("IA__gdk_keymap_add_virtual_modifiers"), visibility("default")));

#undef gdk_keymap_map_virtual_modifiers 
extern __typeof (gdk_keymap_map_virtual_modifiers) gdk_keymap_map_virtual_modifiers __attribute((alias("IA__gdk_keymap_map_virtual_modifiers"), visibility("default")));

#undef gdk_keyval_convert_case 
extern __typeof (gdk_keyval_convert_case) gdk_keyval_convert_case __attribute((alias("IA__gdk_keyval_convert_case"), visibility("default")));

#undef gdk_keyval_from_name 
extern __typeof (gdk_keyval_from_name) gdk_keyval_from_name __attribute((alias("IA__gdk_keyval_from_name"), visibility("default")));

#undef gdk_keyval_name 
extern __typeof (gdk_keyval_name) gdk_keyval_name __attribute((alias("IA__gdk_keyval_name"), visibility("default")));

#endif
#endif
#if IN_HEADER(__GDK_KEYS_H__)
#if IN_FILE(__GDK_KEYS_DIRECTFB_C__)
#undef gdk_keymap_get_direction 
extern __typeof (gdk_keymap_get_direction) gdk_keymap_get_direction __attribute((alias("IA__gdk_keymap_get_direction"), visibility("default")));

#undef gdk_keymap_get_entries_for_keycode 
extern __typeof (gdk_keymap_get_entries_for_keycode) gdk_keymap_get_entries_for_keycode __attribute((alias("IA__gdk_keymap_get_entries_for_keycode"), visibility("default")));

#undef gdk_keymap_get_entries_for_keyval 
extern __typeof (gdk_keymap_get_entries_for_keyval) gdk_keymap_get_entries_for_keyval __attribute((alias("IA__gdk_keymap_get_entries_for_keyval"), visibility("default")));

#undef gdk_keymap_get_for_display 
extern __typeof (gdk_keymap_get_for_display) gdk_keymap_get_for_display __attribute((alias("IA__gdk_keymap_get_for_display"), visibility("default")));

#undef gdk_keymap_get_caps_lock_state 
extern __typeof (gdk_keymap_get_caps_lock_state) gdk_keymap_get_caps_lock_state __attribute((alias("IA__gdk_keymap_get_caps_lock_state"), visibility("default")));

#undef gdk_keymap_lookup_key 
extern __typeof (gdk_keymap_lookup_key) gdk_keymap_lookup_key __attribute((alias("IA__gdk_keymap_lookup_key"), visibility("default")));

#undef gdk_keymap_translate_keyboard_state 
extern __typeof (gdk_keymap_translate_keyboard_state) gdk_keymap_translate_keyboard_state __attribute((alias("IA__gdk_keymap_translate_keyboard_state"), visibility("default")));

#undef gdk_keymap_add_virtual_modifiers 
extern __typeof (gdk_keymap_add_virtual_modifiers) gdk_keymap_add_virtual_modifiers __attribute((alias("IA__gdk_keymap_add_virtual_modifiers"), visibility("default")));

#undef gdk_keymap_map_virtual_modifiers 
extern __typeof (gdk_keymap_map_virtual_modifiers) gdk_keymap_map_virtual_modifiers __attribute((alias("IA__gdk_keymap_map_virtual_modifiers"), visibility("default")));

#undef gdk_keyval_from_name 
extern __typeof (gdk_keyval_from_name) gdk_keyval_from_name __attribute((alias("IA__gdk_keyval_from_name"), visibility("default")));

#undef gdk_keyval_name 
extern __typeof (gdk_keyval_name) gdk_keyval_name __attribute((alias("IA__gdk_keyval_name"), visibility("default")));

#endif
#endif
#if IN_HEADER(__GDK_VISUAL_H__)
#if IN_FILE(__GDK_VISUAL_C__)
#undef gdk_list_visuals 
extern __typeof (gdk_list_visuals) gdk_list_visuals __attribute((alias("IA__gdk_list_visuals"), visibility("default")));

#undef gdk_visual_get_bits_per_rgb 
extern __typeof (gdk_visual_get_bits_per_rgb) gdk_visual_get_bits_per_rgb __attribute((alias("IA__gdk_visual_get_bits_per_rgb"), visibility("default")));

#undef gdk_visual_get_blue_pixel_details 
extern __typeof (gdk_visual_get_blue_pixel_details) gdk_visual_get_blue_pixel_details __attribute((alias("IA__gdk_visual_get_blue_pixel_details"), visibility("default")));

#undef gdk_visual_get_byte_order 
extern __typeof (gdk_visual_get_byte_order) gdk_visual_get_byte_order __attribute((alias("IA__gdk_visual_get_byte_order"), visibility("default")));

#undef gdk_visual_get_colormap_size 
extern __typeof (gdk_visual_get_colormap_size) gdk_visual_get_colormap_size __attribute((alias("IA__gdk_visual_get_colormap_size"), visibility("default")));

#undef gdk_visual_get_depth 
extern __typeof (gdk_visual_get_depth) gdk_visual_get_depth __attribute((alias("IA__gdk_visual_get_depth"), visibility("default")));

#undef gdk_visual_get_green_pixel_details 
extern __typeof (gdk_visual_get_green_pixel_details) gdk_visual_get_green_pixel_details __attribute((alias("IA__gdk_visual_get_green_pixel_details"), visibility("default")));

#undef gdk_visual_get_red_pixel_details 
extern __typeof (gdk_visual_get_red_pixel_details) gdk_visual_get_red_pixel_details __attribute((alias("IA__gdk_visual_get_red_pixel_details"), visibility("default")));

#undef gdk_visual_get_system 
extern __typeof (gdk_visual_get_system) gdk_visual_get_system __attribute((alias("IA__gdk_visual_get_system"), visibility("default")));

#undef gdk_visual_get_visual_type 
extern __typeof (gdk_visual_get_visual_type) gdk_visual_get_visual_type __attribute((alias("IA__gdk_visual_get_visual_type"), visibility("default")));

#endif
#endif
#if IN_HEADER(__GDK_VISUAL_H__)
#if IN_FILE(__GDK_VISUAL_X11_C__)
#undef gdk_query_depths 
extern __typeof (gdk_query_depths) gdk_query_depths __attribute((alias("IA__gdk_query_depths"), visibility("default")));

#undef gdk_query_visual_types 
extern __typeof (gdk_query_visual_types) gdk_query_visual_types __attribute((alias("IA__gdk_query_visual_types"), visibility("default")));

#undef gdk_visual_get_best 
extern __typeof (gdk_visual_get_best) gdk_visual_get_best __attribute((alias("IA__gdk_visual_get_best"), visibility("default")));

#undef gdk_visual_get_best_depth 
extern __typeof (gdk_visual_get_best_depth) gdk_visual_get_best_depth __attribute((alias("IA__gdk_visual_get_best_depth"), visibility("default")));

#undef gdk_visual_get_best_type 
extern __typeof (gdk_visual_get_best_type) gdk_visual_get_best_type __attribute((alias("IA__gdk_visual_get_best_type"), visibility("default")));

#undef gdk_visual_get_best_with_both 
extern __typeof (gdk_visual_get_best_with_both) gdk_visual_get_best_with_both __attribute((alias("IA__gdk_visual_get_best_with_both"), visibility("default")));

#undef gdk_visual_get_best_with_depth 
extern __typeof (gdk_visual_get_best_with_depth) gdk_visual_get_best_with_depth __attribute((alias("IA__gdk_visual_get_best_with_depth"), visibility("default")));

#undef gdk_visual_get_best_with_type 
extern __typeof (gdk_visual_get_best_with_type) gdk_visual_get_best_with_type __attribute((alias("IA__gdk_visual_get_best_with_type"), visibility("default")));

#undef gdk_visual_get_screen 
extern __typeof (gdk_visual_get_screen) gdk_visual_get_screen __attribute((alias("IA__gdk_visual_get_screen"), visibility("default")));

#undef gdk_visual_get_type 
extern __typeof (gdk_visual_get_type) gdk_visual_get_type __attribute((alias("IA__gdk_visual_get_type"), visibility("default")));

#endif
#endif
#if IN_HEADER(__GDK_X_H__)
#if IN_FILE(__GDK_EVENTS_X11_C__)
#ifndef GDK_DISABLE_DEPRECATED
#undef gdk_net_wm_supports 
extern __typeof (gdk_net_wm_supports) gdk_net_wm_supports __attribute((alias("IA__gdk_net_wm_supports"), visibility("default")));

#endif
#endif
#endif
#if IN_HEADER(__GDK_PANGO_H__)
#if IN_FILE(__GDK_PANGO_C__)
#undef gdk_pango_attr_emboss_color_new 
extern __typeof (gdk_pango_attr_emboss_color_new) gdk_pango_attr_emboss_color_new __attribute((alias("IA__gdk_pango_attr_emboss_color_new"), visibility("default")));

#undef gdk_pango_attr_embossed_new 
extern __typeof (gdk_pango_attr_embossed_new) gdk_pango_attr_embossed_new __attribute((alias("IA__gdk_pango_attr_embossed_new"), visibility("default")));

#undef gdk_pango_attr_stipple_new 
extern __typeof (gdk_pango_attr_stipple_new) gdk_pango_attr_stipple_new __attribute((alias("IA__gdk_pango_attr_stipple_new"), visibility("default")));

#undef gdk_pango_context_get 
extern __typeof (gdk_pango_context_get) gdk_pango_context_get __attribute((alias("IA__gdk_pango_context_get"), visibility("default")));

#undef gdk_pango_context_get_for_screen 
extern __typeof (gdk_pango_context_get_for_screen) gdk_pango_context_get_for_screen __attribute((alias("IA__gdk_pango_context_get_for_screen"), visibility("default")));

#ifndef GDK_DISABLE_DEPRECATED
#undef gdk_pango_context_set_colormap 
extern __typeof (gdk_pango_context_set_colormap) gdk_pango_context_set_colormap __attribute((alias("IA__gdk_pango_context_set_colormap"), visibility("default")));

#endif
#undef gdk_pango_layout_get_clip_region 
extern __typeof (gdk_pango_layout_get_clip_region) gdk_pango_layout_get_clip_region __attribute((alias("IA__gdk_pango_layout_get_clip_region"), visibility("default")));

#undef gdk_pango_layout_line_get_clip_region 
extern __typeof (gdk_pango_layout_line_get_clip_region) gdk_pango_layout_line_get_clip_region __attribute((alias("IA__gdk_pango_layout_line_get_clip_region"), visibility("default")));

#undef gdk_pango_renderer_get_default 
extern __typeof (gdk_pango_renderer_get_default) gdk_pango_renderer_get_default __attribute((alias("IA__gdk_pango_renderer_get_default"), visibility("default")));

#undef gdk_pango_renderer_get_type 
extern __typeof (gdk_pango_renderer_get_type) gdk_pango_renderer_get_type __attribute((alias("IA__gdk_pango_renderer_get_type"), visibility("default")));

#undef gdk_pango_renderer_new 
extern __typeof (gdk_pango_renderer_new) gdk_pango_renderer_new __attribute((alias("IA__gdk_pango_renderer_new"), visibility("default")));

#undef gdk_pango_renderer_set_drawable 
extern __typeof (gdk_pango_renderer_set_drawable) gdk_pango_renderer_set_drawable __attribute((alias("IA__gdk_pango_renderer_set_drawable"), visibility("default")));

#undef gdk_pango_renderer_set_gc 
extern __typeof (gdk_pango_renderer_set_gc) gdk_pango_renderer_set_gc __attribute((alias("IA__gdk_pango_renderer_set_gc"), visibility("default")));

#undef gdk_pango_renderer_set_override_color 
extern __typeof (gdk_pango_renderer_set_override_color) gdk_pango_renderer_set_override_color __attribute((alias("IA__gdk_pango_renderer_set_override_color"), visibility("default")));

#undef gdk_pango_renderer_set_stipple 
extern __typeof (gdk_pango_renderer_set_stipple) gdk_pango_renderer_set_stipple __attribute((alias("IA__gdk_pango_renderer_set_stipple"), visibility("default")));

#endif
#endif
#if IN_HEADER(__GDK_PIXBUF_H__)
#if IN_FILE(__GDK_PIXBUF_DRAWABLE_C__)
#undef gdk_pixbuf_get_from_drawable 
extern __typeof (gdk_pixbuf_get_from_drawable) gdk_pixbuf_get_from_drawable __attribute((alias("IA__gdk_pixbuf_get_from_drawable"), visibility("default")));

#undef gdk_pixbuf_get_from_image 
extern __typeof (gdk_pixbuf_get_from_image) gdk_pixbuf_get_from_image __attribute((alias("IA__gdk_pixbuf_get_from_image"), visibility("default")));

#endif
#endif
#if IN_HEADER(__GDK_PIXBUF_H__)
#if IN_FILE(__GDK_PIXBUF_RENDER_C__)
#undef gdk_pixbuf_render_pixmap_and_mask 
extern __typeof (gdk_pixbuf_render_pixmap_and_mask) gdk_pixbuf_render_pixmap_and_mask __attribute((alias("IA__gdk_pixbuf_render_pixmap_and_mask"), visibility("default")));

#undef gdk_pixbuf_render_pixmap_and_mask_for_colormap 
extern __typeof (gdk_pixbuf_render_pixmap_and_mask_for_colormap) gdk_pixbuf_render_pixmap_and_mask_for_colormap __attribute((alias("IA__gdk_pixbuf_render_pixmap_and_mask_for_colormap"), visibility("default")));

#undef gdk_pixbuf_render_threshold_alpha 
extern __typeof (gdk_pixbuf_render_threshold_alpha) gdk_pixbuf_render_threshold_alpha __attribute((alias("IA__gdk_pixbuf_render_threshold_alpha"), visibility("default")));

#ifndef GDK_DISABLE_DEPRECATED
#undef gdk_pixbuf_render_to_drawable 
extern __typeof (gdk_pixbuf_render_to_drawable) gdk_pixbuf_render_to_drawable __attribute((alias("IA__gdk_pixbuf_render_to_drawable"), visibility("default")));

#undef gdk_pixbuf_render_to_drawable_alpha 
extern __typeof (gdk_pixbuf_render_to_drawable_alpha) gdk_pixbuf_render_to_drawable_alpha __attribute((alias("IA__gdk_pixbuf_render_to_drawable_alpha"), visibility("default")));

#endif
#endif
#endif
#if IN_HEADER(__GDK_PIXMAP_H__)
#if IN_FILE(__GDK_PIXMAP_C__)
#undef gdk_bitmap_create_from_data 
extern __typeof (gdk_bitmap_create_from_data) gdk_bitmap_create_from_data __attribute((alias("IA__gdk_bitmap_create_from_data"), visibility("default")));

#undef gdk_pixmap_colormap_create_from_xpm 
extern __typeof (gdk_pixmap_colormap_create_from_xpm) gdk_pixmap_colormap_create_from_xpm __attribute((alias("IA__gdk_pixmap_colormap_create_from_xpm"), visibility("default")));

#undef gdk_pixmap_create_from_data 
extern __typeof (gdk_pixmap_create_from_data) gdk_pixmap_create_from_data __attribute((alias("IA__gdk_pixmap_create_from_data"), visibility("default")));

#undef gdk_pixmap_create_from_xpm 
extern __typeof (gdk_pixmap_create_from_xpm) gdk_pixmap_create_from_xpm __attribute((alias("IA__gdk_pixmap_create_from_xpm"), visibility("default")));

#undef gdk_pixmap_colormap_create_from_xpm_d 
extern __typeof (gdk_pixmap_colormap_create_from_xpm_d) gdk_pixmap_colormap_create_from_xpm_d __attribute((alias("IA__gdk_pixmap_colormap_create_from_xpm_d"), visibility("default")));

#undef gdk_pixmap_create_from_xpm_d 
extern __typeof (gdk_pixmap_create_from_xpm_d) gdk_pixmap_create_from_xpm_d __attribute((alias("IA__gdk_pixmap_create_from_xpm_d"), visibility("default")));

#undef gdk_pixmap_get_size 
extern __typeof (gdk_pixmap_get_size) gdk_pixmap_get_size __attribute((alias("IA__gdk_pixmap_get_size"), visibility("default")));

#undef gdk_pixmap_get_type 
extern __typeof (gdk_pixmap_get_type) gdk_pixmap_get_type __attribute((alias("IA__gdk_pixmap_get_type"), visibility("default")));

#undef gdk_pixmap_new 
extern __typeof (gdk_pixmap_new) gdk_pixmap_new __attribute((alias("IA__gdk_pixmap_new"), visibility("default")));

#endif
#endif
#if IN_HEADER(__GDK_PIXMAP_H__)
#if IN_FILE(__GDK_PIXMAP_X11_C__)
#undef gdk_pixmap_foreign_new 
extern __typeof (gdk_pixmap_foreign_new) gdk_pixmap_foreign_new __attribute((alias("IA__gdk_pixmap_foreign_new"), visibility("default")));

#undef gdk_pixmap_foreign_new_for_display 
extern __typeof (gdk_pixmap_foreign_new_for_display) gdk_pixmap_foreign_new_for_display __attribute((alias("IA__gdk_pixmap_foreign_new_for_display"), visibility("default")));

#undef gdk_pixmap_foreign_new_for_screen 
extern __typeof (gdk_pixmap_foreign_new_for_screen) gdk_pixmap_foreign_new_for_screen __attribute((alias("IA__gdk_pixmap_foreign_new_for_screen"), visibility("default")));

#undef gdk_pixmap_lookup 
extern __typeof (gdk_pixmap_lookup) gdk_pixmap_lookup __attribute((alias("IA__gdk_pixmap_lookup"), visibility("default")));

#undef gdk_pixmap_lookup_for_display 
extern __typeof (gdk_pixmap_lookup_for_display) gdk_pixmap_lookup_for_display __attribute((alias("IA__gdk_pixmap_lookup_for_display"), visibility("default")));

#endif
#endif
#if IN_HEADER(__GDK_REGION_H__)
#if IN_FILE(__GDK_REGION_GENERIC_C__)
#undef gdk_region_copy 
extern __typeof (gdk_region_copy) gdk_region_copy __attribute((alias("IA__gdk_region_copy"), visibility("default")));

#undef gdk_region_destroy 
extern __typeof (gdk_region_destroy) gdk_region_destroy __attribute((alias("IA__gdk_region_destroy"), visibility("default")));

#undef gdk_region_empty 
extern __typeof (gdk_region_empty) gdk_region_empty __attribute((alias("IA__gdk_region_empty"), visibility("default")));

#undef gdk_region_equal 
extern __typeof (gdk_region_equal) gdk_region_equal __attribute((alias("IA__gdk_region_equal"), visibility("default")));

#ifndef GDK_DISABLE_DEPRECATED
#undef gdk_region_rect_equal 
extern __typeof (gdk_region_rect_equal) gdk_region_rect_equal __attribute((alias("IA__gdk_region_rect_equal"), visibility("default")));

#endif
#undef gdk_region_get_clipbox 
extern __typeof (gdk_region_get_clipbox) gdk_region_get_clipbox __attribute((alias("IA__gdk_region_get_clipbox"), visibility("default")));

#undef gdk_region_get_rectangles 
extern __typeof (gdk_region_get_rectangles) gdk_region_get_rectangles __attribute((alias("IA__gdk_region_get_rectangles"), visibility("default")));

#undef gdk_region_intersect 
extern __typeof (gdk_region_intersect) gdk_region_intersect __attribute((alias("IA__gdk_region_intersect"), visibility("default")));

#undef gdk_region_new 
extern __typeof (gdk_region_new) gdk_region_new __attribute((alias("IA__gdk_region_new"), visibility("default")));

#undef gdk_region_offset 
extern __typeof (gdk_region_offset) gdk_region_offset __attribute((alias("IA__gdk_region_offset"), visibility("default")));

#undef gdk_region_point_in 
extern __typeof (gdk_region_point_in) gdk_region_point_in __attribute((alias("IA__gdk_region_point_in"), visibility("default")));

#undef gdk_region_rectangle 
extern __typeof (gdk_region_rectangle) gdk_region_rectangle __attribute((alias("IA__gdk_region_rectangle"), visibility("default")));

#undef gdk_region_rect_in 
extern __typeof (gdk_region_rect_in) gdk_region_rect_in __attribute((alias("IA__gdk_region_rect_in"), visibility("default")));

#ifndef GDK_DISABLE_DEPRECATED
#undef gdk_region_shrink 
extern __typeof (gdk_region_shrink) gdk_region_shrink __attribute((alias("IA__gdk_region_shrink"), visibility("default")));

#undef gdk_region_spans_intersect_foreach 
extern __typeof (gdk_region_spans_intersect_foreach) gdk_region_spans_intersect_foreach __attribute((alias("IA__gdk_region_spans_intersect_foreach"), visibility("default")));

#endif
#undef gdk_region_subtract 
extern __typeof (gdk_region_subtract) gdk_region_subtract __attribute((alias("IA__gdk_region_subtract"), visibility("default")));

#undef gdk_region_union 
extern __typeof (gdk_region_union) gdk_region_union __attribute((alias("IA__gdk_region_union"), visibility("default")));

#undef gdk_region_union_with_rect 
extern __typeof (gdk_region_union_with_rect) gdk_region_union_with_rect __attribute((alias("IA__gdk_region_union_with_rect"), visibility("default")));

#ifndef GDK_DISABLE_DEPRECATED
#undef gdk_region_xor 
extern __typeof (gdk_region_xor) gdk_region_xor __attribute((alias("IA__gdk_region_xor"), visibility("default")));

#endif
#endif
#endif
#if IN_HEADER(__GDK_REGION_H__)
#if IN_FILE(__GDK_POLYREG_GENERIC_C__)
#ifndef GDK_DISABLE_DEPRECATED
#undef gdk_region_polygon 
extern __typeof (gdk_region_polygon) gdk_region_polygon __attribute((alias("IA__gdk_region_polygon"), visibility("default")));

#endif
#endif
#endif
#if IN_HEADER(__GDK_RGB_H__)
#if IN_FILE(__GDK_RGB_C__)
#undef gdk_rgb_cmap_free 
extern __typeof (gdk_rgb_cmap_free) gdk_rgb_cmap_free __attribute((alias("IA__gdk_rgb_cmap_free"), visibility("default")));

#undef gdk_rgb_cmap_new 
extern __typeof (gdk_rgb_cmap_new) gdk_rgb_cmap_new __attribute((alias("IA__gdk_rgb_cmap_new"), visibility("default")));

#undef gdk_rgb_colormap_ditherable 
extern __typeof (gdk_rgb_colormap_ditherable) gdk_rgb_colormap_ditherable __attribute((alias("IA__gdk_rgb_colormap_ditherable"), visibility("default")));

#undef gdk_rgb_ditherable 
extern __typeof (gdk_rgb_ditherable) gdk_rgb_ditherable __attribute((alias("IA__gdk_rgb_ditherable"), visibility("default")));

#undef gdk_rgb_find_color 
extern __typeof (gdk_rgb_find_color) gdk_rgb_find_color __attribute((alias("IA__gdk_rgb_find_color"), visibility("default")));

#undef gdk_rgb_get_colormap 
extern __typeof (gdk_rgb_get_colormap) gdk_rgb_get_colormap __attribute((alias("IA__gdk_rgb_get_colormap"), visibility("default")));

#undef gdk_rgb_get_visual 
extern __typeof (gdk_rgb_get_visual) gdk_rgb_get_visual __attribute((alias("IA__gdk_rgb_get_visual"), visibility("default")));

#ifndef GDK_DISABLE_DEPRECATED
#undef gdk_rgb_init 
extern __typeof (gdk_rgb_init) gdk_rgb_init __attribute((alias("IA__gdk_rgb_init"), visibility("default")));

#undef gdk_rgb_xpixel_from_rgb 
extern __typeof (gdk_rgb_xpixel_from_rgb) gdk_rgb_xpixel_from_rgb __attribute((alias("IA__gdk_rgb_xpixel_from_rgb"), visibility("default")));

#undef gdk_rgb_gc_set_background 
extern __typeof (gdk_rgb_gc_set_background) gdk_rgb_gc_set_background __attribute((alias("IA__gdk_rgb_gc_set_background"), visibility("default")));

#undef gdk_rgb_gc_set_foreground 
extern __typeof (gdk_rgb_gc_set_foreground) gdk_rgb_gc_set_foreground __attribute((alias("IA__gdk_rgb_gc_set_foreground"), visibility("default")));

#endif
#undef gdk_rgb_set_install 
extern __typeof (gdk_rgb_set_install) gdk_rgb_set_install __attribute((alias("IA__gdk_rgb_set_install"), visibility("default")));

#undef gdk_rgb_set_min_colors 
extern __typeof (gdk_rgb_set_min_colors) gdk_rgb_set_min_colors __attribute((alias("IA__gdk_rgb_set_min_colors"), visibility("default")));

#undef gdk_rgb_set_verbose 
extern __typeof (gdk_rgb_set_verbose) gdk_rgb_set_verbose __attribute((alias("IA__gdk_rgb_set_verbose"), visibility("default")));

#undef gdk_draw_gray_image 
extern __typeof (gdk_draw_gray_image) gdk_draw_gray_image __attribute((alias("IA__gdk_draw_gray_image"), visibility("default")));

#undef gdk_draw_indexed_image 
extern __typeof (gdk_draw_indexed_image) gdk_draw_indexed_image __attribute((alias("IA__gdk_draw_indexed_image"), visibility("default")));

#undef gdk_draw_rgb_32_image 
extern __typeof (gdk_draw_rgb_32_image) gdk_draw_rgb_32_image __attribute((alias("IA__gdk_draw_rgb_32_image"), visibility("default")));

#undef gdk_draw_rgb_32_image_dithalign 
extern __typeof (gdk_draw_rgb_32_image_dithalign) gdk_draw_rgb_32_image_dithalign __attribute((alias("IA__gdk_draw_rgb_32_image_dithalign"), visibility("default")));

#undef gdk_draw_rgb_image 
extern __typeof (gdk_draw_rgb_image) gdk_draw_rgb_image __attribute((alias("IA__gdk_draw_rgb_image"), visibility("default")));

#undef gdk_draw_rgb_image_dithalign 
extern __typeof (gdk_draw_rgb_image_dithalign) gdk_draw_rgb_image_dithalign __attribute((alias("IA__gdk_draw_rgb_image_dithalign"), visibility("default")));

#endif
#endif
#if IN_HEADER(__GDK_SCREEN_H__)
#if IN_FILE(__GDK_SCREEN_C__)
#undef gdk_screen_get_type 
extern __typeof (gdk_screen_get_type) gdk_screen_get_type __attribute((alias("IA__gdk_screen_get_type"), visibility("default")));

#undef gdk_screen_get_monitor_at_point 
extern __typeof (gdk_screen_get_monitor_at_point) gdk_screen_get_monitor_at_point __attribute((alias("IA__gdk_screen_get_monitor_at_point"), visibility("default")));

#undef gdk_screen_get_monitor_at_window 
extern __typeof (gdk_screen_get_monitor_at_window) gdk_screen_get_monitor_at_window __attribute((alias("IA__gdk_screen_get_monitor_at_window"), visibility("default")));

#undef gdk_screen_set_font_options 
extern __typeof (gdk_screen_set_font_options) gdk_screen_set_font_options __attribute((alias("IA__gdk_screen_set_font_options"), visibility("default")));

#undef gdk_screen_get_font_options 
extern __typeof (gdk_screen_get_font_options) gdk_screen_get_font_options __attribute((alias("IA__gdk_screen_get_font_options"), visibility("default")));

#undef gdk_screen_set_resolution 
extern __typeof (gdk_screen_set_resolution) gdk_screen_set_resolution __attribute((alias("IA__gdk_screen_set_resolution"), visibility("default")));

#undef gdk_screen_get_resolution 
extern __typeof (gdk_screen_get_resolution) gdk_screen_get_resolution __attribute((alias("IA__gdk_screen_get_resolution"), visibility("default")));

#endif
#endif
#if IN_HEADER(__GDK_SCREEN_H__)
#if IN_FILE(__GDK_DISPLAY_MANAGER_C__)
#undef gdk_screen_get_default 
extern __typeof (gdk_screen_get_default) gdk_screen_get_default __attribute((alias("IA__gdk_screen_get_default"), visibility("default")));

#endif
#endif
#if IN_HEADER(__GDK_SCREEN_H__)
#if IN_FILE(__GDK_RGB_C__)
#undef gdk_screen_get_rgb_colormap 
extern __typeof (gdk_screen_get_rgb_colormap) gdk_screen_get_rgb_colormap __attribute((alias("IA__gdk_screen_get_rgb_colormap"), visibility("default")));

#undef gdk_screen_get_rgb_visual 
extern __typeof (gdk_screen_get_rgb_visual) gdk_screen_get_rgb_visual __attribute((alias("IA__gdk_screen_get_rgb_visual"), visibility("default")));

#endif
#endif
#if IN_HEADER(__GDK_SCREEN_H__)
#if IN_FILE(__GDK_EVENTS_X11_C__)
#undef gdk_screen_get_setting 
extern __typeof (gdk_screen_get_setting) gdk_screen_get_setting __attribute((alias("IA__gdk_screen_get_setting"), visibility("default")));

#undef gdk_screen_broadcast_client_message 
extern __typeof (gdk_screen_broadcast_client_message) gdk_screen_broadcast_client_message __attribute((alias("IA__gdk_screen_broadcast_client_message"), visibility("default")));

#endif
#endif
#if IN_HEADER(__GDK_SCREEN_H__)
#if IN_FILE(__GDK_VISUAL_X11_C__)
#undef gdk_screen_get_system_visual 
extern __typeof (gdk_screen_get_system_visual) gdk_screen_get_system_visual __attribute((alias("IA__gdk_screen_get_system_visual"), visibility("default")));

#undef gdk_screen_list_visuals 
extern __typeof (gdk_screen_list_visuals) gdk_screen_list_visuals __attribute((alias("IA__gdk_screen_list_visuals"), visibility("default")));

#endif
#endif
#if IN_HEADER(__GDK_SCREEN_H__)
#if IN_FILE(__GDK_WINDOW_C__)
#undef gdk_screen_get_toplevel_windows 
extern __typeof (gdk_screen_get_toplevel_windows) gdk_screen_get_toplevel_windows __attribute((alias("IA__gdk_screen_get_toplevel_windows"), visibility("default")));

#endif
#endif
#if IN_HEADER(__GDK_SCREEN_H__)
#if IN_FILE(__GDK_SCREEN_X11_C__)
#undef gdk_screen_get_display 
extern __typeof (gdk_screen_get_display) gdk_screen_get_display __attribute((alias("IA__gdk_screen_get_display"), visibility("default")));

#undef gdk_screen_get_width 
extern __typeof (gdk_screen_get_width) gdk_screen_get_width __attribute((alias("IA__gdk_screen_get_width"), visibility("default")));

#undef gdk_screen_get_width_mm 
extern __typeof (gdk_screen_get_width_mm) gdk_screen_get_width_mm __attribute((alias("IA__gdk_screen_get_width_mm"), visibility("default")));

#undef gdk_screen_get_height 
extern __typeof (gdk_screen_get_height) gdk_screen_get_height __attribute((alias("IA__gdk_screen_get_height"), visibility("default")));

#undef gdk_screen_get_height_mm 
extern __typeof (gdk_screen_get_height_mm) gdk_screen_get_height_mm __attribute((alias("IA__gdk_screen_get_height_mm"), visibility("default")));

#undef gdk_screen_get_number 
extern __typeof (gdk_screen_get_number) gdk_screen_get_number __attribute((alias("IA__gdk_screen_get_number"), visibility("default")));

#undef gdk_screen_get_primary_monitor 
extern __typeof (gdk_screen_get_primary_monitor) gdk_screen_get_primary_monitor __attribute((alias("IA__gdk_screen_get_primary_monitor"), visibility("default")));

#undef gdk_screen_get_root_window 
extern __typeof (gdk_screen_get_root_window) gdk_screen_get_root_window __attribute((alias("IA__gdk_screen_get_root_window"), visibility("default")));

#undef gdk_screen_get_default_colormap 
extern __typeof (gdk_screen_get_default_colormap) gdk_screen_get_default_colormap __attribute((alias("IA__gdk_screen_get_default_colormap"), visibility("default")));

#undef gdk_screen_set_default_colormap 
extern __typeof (gdk_screen_set_default_colormap) gdk_screen_set_default_colormap __attribute((alias("IA__gdk_screen_set_default_colormap"), visibility("default")));

#undef gdk_screen_get_n_monitors 
extern __typeof (gdk_screen_get_n_monitors) gdk_screen_get_n_monitors __attribute((alias("IA__gdk_screen_get_n_monitors"), visibility("default")));

#undef gdk_screen_get_monitor_geometry 
extern __typeof (gdk_screen_get_monitor_geometry) gdk_screen_get_monitor_geometry __attribute((alias("IA__gdk_screen_get_monitor_geometry"), visibility("default")));

#undef gdk_screen_get_monitor_width_mm 
extern __typeof (gdk_screen_get_monitor_width_mm) gdk_screen_get_monitor_width_mm __attribute((alias("IA__gdk_screen_get_monitor_width_mm"), visibility("default")));

#undef gdk_screen_get_monitor_height_mm 
extern __typeof (gdk_screen_get_monitor_height_mm) gdk_screen_get_monitor_height_mm __attribute((alias("IA__gdk_screen_get_monitor_height_mm"), visibility("default")));

#undef gdk_screen_get_monitor_plug_name 
extern __typeof (gdk_screen_get_monitor_plug_name) gdk_screen_get_monitor_plug_name __attribute((alias("IA__gdk_screen_get_monitor_plug_name"), visibility("default")));

#undef gdk_screen_get_rgba_colormap 
extern __typeof (gdk_screen_get_rgba_colormap) gdk_screen_get_rgba_colormap __attribute((alias("IA__gdk_screen_get_rgba_colormap"), visibility("default")));

#undef gdk_screen_get_rgba_visual 
extern __typeof (gdk_screen_get_rgba_visual) gdk_screen_get_rgba_visual __attribute((alias("IA__gdk_screen_get_rgba_visual"), visibility("default")));

#undef gdk_screen_get_active_window 
extern __typeof (gdk_screen_get_active_window) gdk_screen_get_active_window __attribute((alias("IA__gdk_screen_get_active_window"), visibility("default")));

#undef gdk_screen_get_window_stack 
extern __typeof (gdk_screen_get_window_stack) gdk_screen_get_window_stack __attribute((alias("IA__gdk_screen_get_window_stack"), visibility("default")));

#undef gdk_screen_is_composited 
extern __typeof (gdk_screen_is_composited) gdk_screen_is_composited __attribute((alias("IA__gdk_screen_is_composited"), visibility("default")));

#undef gdk_screen_make_display_name 
extern __typeof (gdk_screen_make_display_name) gdk_screen_make_display_name __attribute((alias("IA__gdk_screen_make_display_name"), visibility("default")));

#endif
#endif
#if IN_HEADER(__GDK_SCREEN_H__)
#if IN_FILE(__GDK_COLOR_X11_C__)
#undef gdk_screen_get_system_colormap 
extern __typeof (gdk_screen_get_system_colormap) gdk_screen_get_system_colormap __attribute((alias("IA__gdk_screen_get_system_colormap"), visibility("default")));

#endif
#endif
#if IN_HEADER(__GDK_SELECTION_H__)
#if IN_FILE(__GDK_SELECTION_C__)
#undef gdk_selection_owner_set 
extern __typeof (gdk_selection_owner_set) gdk_selection_owner_set __attribute((alias("IA__gdk_selection_owner_set"), visibility("default")));

#undef gdk_selection_owner_get 
extern __typeof (gdk_selection_owner_get) gdk_selection_owner_get __attribute((alias("IA__gdk_selection_owner_get"), visibility("default")));

#undef gdk_selection_send_notify 
extern __typeof (gdk_selection_send_notify) gdk_selection_send_notify __attribute((alias("IA__gdk_selection_send_notify"), visibility("default")));

#endif
#endif
#if IN_HEADER(__GDK_SELECTION_H__)
#if IN_FILE(__GDK_SELECTION_X11_C__)
#undef gdk_selection_convert 
extern __typeof (gdk_selection_convert) gdk_selection_convert __attribute((alias("IA__gdk_selection_convert"), visibility("default")));

#undef gdk_selection_owner_get_for_display 
extern __typeof (gdk_selection_owner_get_for_display) gdk_selection_owner_get_for_display __attribute((alias("IA__gdk_selection_owner_get_for_display"), visibility("default")));

#undef gdk_selection_owner_set_for_display 
extern __typeof (gdk_selection_owner_set_for_display) gdk_selection_owner_set_for_display __attribute((alias("IA__gdk_selection_owner_set_for_display"), visibility("default")));

#undef gdk_selection_property_get 
extern __typeof (gdk_selection_property_get) gdk_selection_property_get __attribute((alias("IA__gdk_selection_property_get"), visibility("default")));

#undef gdk_selection_send_notify_for_display 
extern __typeof (gdk_selection_send_notify_for_display) gdk_selection_send_notify_for_display __attribute((alias("IA__gdk_selection_send_notify_for_display"), visibility("default")));

#endif
#endif
#if IN_HEADER(__GDK_WINDOW_H__)
#if IN_FILE(__GDK_DISPLAY_C__)
#undef gdk_set_sm_client_id 
extern __typeof (gdk_set_sm_client_id) gdk_set_sm_client_id __attribute((alias("IA__gdk_set_sm_client_id"), visibility("default")));

#endif
#endif
#if IN_HEADER(__GDK_SPAWN_H__)
#if IN_FILE(__GDK_SPAWN_X11_C__)
#ifndef GDK_DISABLE_DEPRECATED
#undef gdk_spawn_command_line_on_screen 
extern __typeof (gdk_spawn_command_line_on_screen) gdk_spawn_command_line_on_screen __attribute((alias("IA__gdk_spawn_command_line_on_screen"), visibility("default")));

#undef gdk_spawn_on_screen 
extern __typeof (gdk_spawn_on_screen) gdk_spawn_on_screen __attribute((alias("IA__gdk_spawn_on_screen"), visibility("default")));

#undef gdk_spawn_on_screen_with_pipes 
extern __typeof (gdk_spawn_on_screen_with_pipes) gdk_spawn_on_screen_with_pipes __attribute((alias("IA__gdk_spawn_on_screen_with_pipes"), visibility("default")));

#endif
#endif
#endif
#if IN_HEADER(__GDK_PRIVATE_H__)
#if IN_FILE(__GDK_EVENTS_C__)
#undef gdk_synthesize_window_state 
extern __typeof (gdk_synthesize_window_state) gdk_synthesize_window_state __attribute((alias("IA__gdk_synthesize_window_state"), visibility("default")));

#endif
#endif
#if IN_HEADER(__GDK_PRIVATE_H__)
#if IN_FILE(__GDK_WINDOW_X11_C__)
#undef gdk_window_destroy_notify 
extern __typeof (gdk_window_destroy_notify) gdk_window_destroy_notify __attribute((alias("IA__gdk_window_destroy_notify"), visibility("default")));

#endif
#endif
#ifdef GDK_WINDOWING_WIN32
#if IN_HEADER(__GDK_WIN32_H__)
#if IN_FILE(__GDK_WINDOW_WIN32_C__)
#undef gdk_win32_window_is_win32 
extern __typeof (gdk_win32_window_is_win32) gdk_win32_window_is_win32 __attribute((alias("IA__gdk_win32_window_is_win32"), visibility("default")));

#undef gdk_win32_window_get_impl_hwnd 
extern __typeof (gdk_win32_window_get_impl_hwnd) gdk_win32_window_get_impl_hwnd __attribute((alias("IA__gdk_win32_window_get_impl_hwnd"), visibility("default")));

#undef gdk_win32_begin_direct_draw_libgtk_only 
extern __typeof (gdk_win32_begin_direct_draw_libgtk_only) gdk_win32_begin_direct_draw_libgtk_only __attribute((alias("IA__gdk_win32_begin_direct_draw_libgtk_only"), visibility("default")));

#undef gdk_win32_end_direct_draw_libgtk_only 
extern __typeof (gdk_win32_end_direct_draw_libgtk_only) gdk_win32_end_direct_draw_libgtk_only __attribute((alias("IA__gdk_win32_end_direct_draw_libgtk_only"), visibility("default")));

#undef gdk_win32_window_lookup_for_display 
extern __typeof (gdk_win32_window_lookup_for_display) gdk_win32_window_lookup_for_display __attribute((alias("IA__gdk_win32_window_lookup_for_display"), visibility("default")));

#undef gdk_win32_window_foreign_new_for_display 
extern __typeof (gdk_win32_window_foreign_new_for_display) gdk_win32_window_foreign_new_for_display __attribute((alias("IA__gdk_win32_window_foreign_new_for_display"), visibility("default")));

#endif
#endif
#if IN_HEADER(__GDK_WIN32_H__)
#if IN_FILE(__GDK_WIN32ID_C__)
#undef gdk_win32_handle_table_lookup 
extern __typeof (gdk_win32_handle_table_lookup) gdk_win32_handle_table_lookup __attribute((alias("IA__gdk_win32_handle_table_lookup"), visibility("default")));

#endif
#endif
#if IN_HEADER(__GDK_WIN32_H__)
#if IN_FILE(__GDK_CURSOR_WIN32_C__)
#undef gdk_win32_icon_to_pixbuf_libgtk_only 
extern __typeof (gdk_win32_icon_to_pixbuf_libgtk_only) gdk_win32_icon_to_pixbuf_libgtk_only __attribute((alias("IA__gdk_win32_icon_to_pixbuf_libgtk_only"), visibility("default")));

#undef gdk_win32_pixbuf_to_hicon_libgtk_only 
extern __typeof (gdk_win32_pixbuf_to_hicon_libgtk_only) gdk_win32_pixbuf_to_hicon_libgtk_only __attribute((alias("IA__gdk_win32_pixbuf_to_hicon_libgtk_only"), visibility("default")));

#endif
#endif
#if IN_HEADER(__GDK_WIN32_H__)
#if IN_FILE(__GDK_DRAWABLE_WIN32_C__)
#undef gdk_win32_drawable_get_handle 
extern __typeof (gdk_win32_drawable_get_handle) gdk_win32_drawable_get_handle __attribute((alias("IA__gdk_win32_drawable_get_handle"), visibility("default")));

#endif
#endif
#if IN_HEADER(__GDK_WIN32_H__)
#if IN_FILE(__GDK_EVENTS_WIN32_C__)
#undef gdk_win32_set_modal_dialog_libgtk_only 
extern __typeof (gdk_win32_set_modal_dialog_libgtk_only) gdk_win32_set_modal_dialog_libgtk_only __attribute((alias("IA__gdk_win32_set_modal_dialog_libgtk_only"), visibility("default")));

#endif
#endif
#if IN_HEADER(__GDK_WIN32_H__)
#if IN_FILE(__GDK_GC_WIN32_C__)
#undef gdk_win32_hdc_get 
extern __typeof (gdk_win32_hdc_get) gdk_win32_hdc_get __attribute((alias("IA__gdk_win32_hdc_get"), visibility("default")));

#undef gdk_win32_hdc_release 
extern __typeof (gdk_win32_hdc_release) gdk_win32_hdc_release __attribute((alias("IA__gdk_win32_hdc_release"), visibility("default")));

#endif
#endif
#if IN_HEADER(__GDK_WIN32_H__)
#if IN_FILE(__GDK_SELECTION_WIN32_C__)
#undef gdk_win32_selection_add_targets 
extern __typeof (gdk_win32_selection_add_targets) gdk_win32_selection_add_targets __attribute((alias("IA__gdk_win32_selection_add_targets"), visibility("default")));

#endif
#endif
#if IN_HEADER(__GDK_WIN32_H__)
#if IN_FILE(__GDK_KEYS_WIN32_C__)
#undef gdk_win32_keymap_get_type 
extern __typeof (gdk_win32_keymap_get_type) gdk_win32_keymap_get_type __attribute((alias("IA__gdk_win32_keymap_get_type"), visibility("default")));

#undef gdk_win32_keymap_check_compose 
extern __typeof (gdk_win32_keymap_check_compose) gdk_win32_keymap_check_compose __attribute((alias("IA__gdk_win32_keymap_check_compose"), visibility("default")));

#endif
#endif
#endif
#ifdef GDK_WINDOWING_X11
#if IN_HEADER(__GDK_X_H__)
#if IN_FILE(__GDK_PROPERTY_X11_C__)
#undef gdk_x11_atom_to_xatom 
extern __typeof (gdk_x11_atom_to_xatom) gdk_x11_atom_to_xatom __attribute((alias("IA__gdk_x11_atom_to_xatom"), visibility("default")));

#undef gdk_x11_atom_to_xatom_for_display 
extern __typeof (gdk_x11_atom_to_xatom_for_display) gdk_x11_atom_to_xatom_for_display __attribute((alias("IA__gdk_x11_atom_to_xatom_for_display"), visibility("default")));

#undef gdk_x11_get_xatom_by_name 
extern __typeof (gdk_x11_get_xatom_by_name) gdk_x11_get_xatom_by_name __attribute((alias("IA__gdk_x11_get_xatom_by_name"), visibility("default")));

#undef gdk_x11_get_xatom_by_name_for_display 
extern __typeof (gdk_x11_get_xatom_by_name_for_display) gdk_x11_get_xatom_by_name_for_display __attribute((alias("IA__gdk_x11_get_xatom_by_name_for_display"), visibility("default")));

#undef gdk_x11_get_xatom_name 
extern __typeof (gdk_x11_get_xatom_name) gdk_x11_get_xatom_name __attribute((alias("IA__gdk_x11_get_xatom_name"), visibility("default")));

#undef gdk_x11_get_xatom_name_for_display 
extern __typeof (gdk_x11_get_xatom_name_for_display) gdk_x11_get_xatom_name_for_display __attribute((alias("IA__gdk_x11_get_xatom_name_for_display"), visibility("default")));

#undef gdk_x11_xatom_to_atom 
extern __typeof (gdk_x11_xatom_to_atom) gdk_x11_xatom_to_atom __attribute((alias("IA__gdk_x11_xatom_to_atom"), visibility("default")));

#undef gdk_x11_xatom_to_atom_for_display 
extern __typeof (gdk_x11_xatom_to_atom_for_display) gdk_x11_xatom_to_atom_for_display __attribute((alias("IA__gdk_x11_xatom_to_atom_for_display"), visibility("default")));

#endif
#if IN_FILE(__GDK_COLOR_X11_C__)
#undef gdk_x11_colormap_foreign_new 
extern __typeof (gdk_x11_colormap_foreign_new) gdk_x11_colormap_foreign_new __attribute((alias("IA__gdk_x11_colormap_foreign_new"), visibility("default")));

#undef gdk_x11_colormap_get_xcolormap 
extern __typeof (gdk_x11_colormap_get_xcolormap) gdk_x11_colormap_get_xcolormap __attribute((alias("IA__gdk_x11_colormap_get_xcolormap"), visibility("default")));

#undef gdk_x11_colormap_get_xdisplay 
extern __typeof (gdk_x11_colormap_get_xdisplay) gdk_x11_colormap_get_xdisplay __attribute((alias("IA__gdk_x11_colormap_get_xdisplay"), visibility("default")));

#ifdef GDK_ENABLE_BROKEN
#undef gdkx_colormap_get 
extern __typeof (gdkx_colormap_get) gdkx_colormap_get __attribute((alias("IA__gdkx_colormap_get"), visibility("default")));

#endif
#endif
#if IN_FILE(__GDK_CURSOR_X11_C__)
#undef gdk_x11_cursor_get_xcursor 
extern __typeof (gdk_x11_cursor_get_xcursor) gdk_x11_cursor_get_xcursor __attribute((alias("IA__gdk_x11_cursor_get_xcursor"), visibility("default")));

#undef gdk_x11_cursor_get_xdisplay 
extern __typeof (gdk_x11_cursor_get_xdisplay) gdk_x11_cursor_get_xdisplay __attribute((alias("IA__gdk_x11_cursor_get_xdisplay"), visibility("default")));

#undef gdk_x11_display_set_cursor_theme 
extern __typeof (gdk_x11_display_set_cursor_theme) gdk_x11_display_set_cursor_theme __attribute((alias("IA__gdk_x11_display_set_cursor_theme"), visibility("default")));

#endif
#if IN_FILE(__GDK_DISPLAY_X11_C__)
#undef gdk_x11_display_get_user_time 
extern __typeof (gdk_x11_display_get_user_time) gdk_x11_display_get_user_time __attribute((alias("IA__gdk_x11_display_get_user_time"), visibility("default")));

#undef gdk_x11_display_get_xdisplay 
extern __typeof (gdk_x11_display_get_xdisplay) gdk_x11_display_get_xdisplay __attribute((alias("IA__gdk_x11_display_get_xdisplay"), visibility("default")));

#undef gdk_x11_display_grab 
extern __typeof (gdk_x11_display_grab) gdk_x11_display_grab __attribute((alias("IA__gdk_x11_display_grab"), visibility("default")));

#undef gdk_x11_display_ungrab 
extern __typeof (gdk_x11_display_ungrab) gdk_x11_display_ungrab __attribute((alias("IA__gdk_x11_display_ungrab"), visibility("default")));

#undef gdk_x11_lookup_xdisplay 
extern __typeof (gdk_x11_lookup_xdisplay) gdk_x11_lookup_xdisplay __attribute((alias("IA__gdk_x11_lookup_xdisplay"), visibility("default")));

#undef gdk_x11_display_broadcast_startup_message 
extern __typeof (gdk_x11_display_broadcast_startup_message) gdk_x11_display_broadcast_startup_message __attribute((alias("IA__gdk_x11_display_broadcast_startup_message"), visibility("default")));

#undef gdk_x11_display_get_startup_notification_id 
extern __typeof (gdk_x11_display_get_startup_notification_id) gdk_x11_display_get_startup_notification_id __attribute((alias("IA__gdk_x11_display_get_startup_notification_id"), visibility("default")));

#endif
#if IN_FILE(__GDK_DRAWABLE_X11_C__)
#undef gdk_x11_drawable_get_xdisplay 
extern __typeof (gdk_x11_drawable_get_xdisplay) gdk_x11_drawable_get_xdisplay __attribute((alias("IA__gdk_x11_drawable_get_xdisplay"), visibility("default")));

#undef gdk_x11_drawable_get_xid 
extern __typeof (gdk_x11_drawable_get_xid) gdk_x11_drawable_get_xid __attribute((alias("IA__gdk_x11_drawable_get_xid"), visibility("default")));

#undef gdk_x11_window_get_drawable_impl 
extern __typeof (gdk_x11_window_get_drawable_impl) gdk_x11_window_get_drawable_impl __attribute((alias("IA__gdk_x11_window_get_drawable_impl"), visibility("default")));

#undef gdk_x11_pixmap_get_drawable_impl 
extern __typeof (gdk_x11_pixmap_get_drawable_impl) gdk_x11_pixmap_get_drawable_impl __attribute((alias("IA__gdk_x11_pixmap_get_drawable_impl"), visibility("default")));

#endif
#if IN_FILE(__GDK_FONT_X11_C__)
#ifndef GDK_DISABLE_DEPRECATED
#undef gdk_x11_font_get_name 
extern __typeof (gdk_x11_font_get_name) gdk_x11_font_get_name __attribute((alias("IA__gdk_x11_font_get_name"), visibility("default")));

#undef gdk_x11_font_get_xdisplay 
extern __typeof (gdk_x11_font_get_xdisplay) gdk_x11_font_get_xdisplay __attribute((alias("IA__gdk_x11_font_get_xdisplay"), visibility("default")));

#endif
#undef gdk_x11_font_get_xfont 
extern __typeof (gdk_x11_font_get_xfont) gdk_x11_font_get_xfont __attribute((alias("IA__gdk_x11_font_get_xfont"), visibility("default")));

#endif
#if IN_FILE(__GDK_GC_X11_C__)
#undef gdk_x11_gc_get_xdisplay 
extern __typeof (gdk_x11_gc_get_xdisplay) gdk_x11_gc_get_xdisplay __attribute((alias("IA__gdk_x11_gc_get_xdisplay"), visibility("default")));

#undef gdk_x11_gc_get_xgc 
extern __typeof (gdk_x11_gc_get_xgc) gdk_x11_gc_get_xgc __attribute((alias("IA__gdk_x11_gc_get_xgc"), visibility("default")));

#endif
#if IN_FILE(__GDK_MAIN_X11_C__)
#undef gdk_x11_get_default_root_xwindow 
extern __typeof (gdk_x11_get_default_root_xwindow) gdk_x11_get_default_root_xwindow __attribute((alias("IA__gdk_x11_get_default_root_xwindow"), visibility("default")));

#undef gdk_x11_get_default_screen 
extern __typeof (gdk_x11_get_default_screen) gdk_x11_get_default_screen __attribute((alias("IA__gdk_x11_get_default_screen"), visibility("default")));

#undef gdk_x11_get_default_xdisplay 
extern __typeof (gdk_x11_get_default_xdisplay) gdk_x11_get_default_xdisplay __attribute((alias("IA__gdk_x11_get_default_xdisplay"), visibility("default")));

#undef gdk_x11_grab_server 
extern __typeof (gdk_x11_grab_server) gdk_x11_grab_server __attribute((alias("IA__gdk_x11_grab_server"), visibility("default")));

#undef gdk_x11_ungrab_server 
extern __typeof (gdk_x11_ungrab_server) gdk_x11_ungrab_server __attribute((alias("IA__gdk_x11_ungrab_server"), visibility("default")));

#undef gdk_x11_set_sm_client_id 
extern __typeof (gdk_x11_set_sm_client_id) gdk_x11_set_sm_client_id __attribute((alias("IA__gdk_x11_set_sm_client_id"), visibility("default")));

#endif
#if IN_FILE(__GDK_EVENTS_X11_C__)
#undef gdk_x11_get_server_time 
extern __typeof (gdk_x11_get_server_time) gdk_x11_get_server_time __attribute((alias("IA__gdk_x11_get_server_time"), visibility("default")));

#undef gdk_x11_register_standard_event_type 
extern __typeof (gdk_x11_register_standard_event_type) gdk_x11_register_standard_event_type __attribute((alias("IA__gdk_x11_register_standard_event_type"), visibility("default")));

#undef gdk_x11_screen_get_window_manager_name 
extern __typeof (gdk_x11_screen_get_window_manager_name) gdk_x11_screen_get_window_manager_name __attribute((alias("IA__gdk_x11_screen_get_window_manager_name"), visibility("default")));

#undef gdk_x11_screen_supports_net_wm_hint 
extern __typeof (gdk_x11_screen_supports_net_wm_hint) gdk_x11_screen_supports_net_wm_hint __attribute((alias("IA__gdk_x11_screen_supports_net_wm_hint"), visibility("default")));

#endif
#if IN_FILE(__GDK_IMAGE_X11_C__)
#undef gdk_x11_image_get_xdisplay 
extern __typeof (gdk_x11_image_get_xdisplay) gdk_x11_image_get_xdisplay __attribute((alias("IA__gdk_x11_image_get_xdisplay"), visibility("default")));

#undef gdk_x11_image_get_ximage 
extern __typeof (gdk_x11_image_get_ximage) gdk_x11_image_get_ximage __attribute((alias("IA__gdk_x11_image_get_ximage"), visibility("default")));

#endif
#if IN_FILE(__GDK_SCREEN_X11_C__)
#undef gdk_x11_screen_get_screen_number 
extern __typeof (gdk_x11_screen_get_screen_number) gdk_x11_screen_get_screen_number __attribute((alias("IA__gdk_x11_screen_get_screen_number"), visibility("default")));

#undef gdk_x11_screen_get_xscreen 
extern __typeof (gdk_x11_screen_get_xscreen) gdk_x11_screen_get_xscreen __attribute((alias("IA__gdk_x11_screen_get_xscreen"), visibility("default")));

#undef gdk_x11_screen_get_monitor_output 
extern __typeof (gdk_x11_screen_get_monitor_output) gdk_x11_screen_get_monitor_output __attribute((alias("IA__gdk_x11_screen_get_monitor_output"), visibility("default")));

#endif
#if IN_FILE(__GDK_VISUAL_X11_C__)
#undef gdk_x11_screen_lookup_visual 
extern __typeof (gdk_x11_screen_lookup_visual) gdk_x11_screen_lookup_visual __attribute((alias("IA__gdk_x11_screen_lookup_visual"), visibility("default")));

#undef gdk_x11_visual_get_xvisual 
extern __typeof (gdk_x11_visual_get_xvisual) gdk_x11_visual_get_xvisual __attribute((alias("IA__gdk_x11_visual_get_xvisual"), visibility("default")));

#ifndef GDK_DISABLE_DEPRECATED
#undef gdkx_visual_get 
extern __typeof (gdkx_visual_get) gdkx_visual_get __attribute((alias("IA__gdkx_visual_get"), visibility("default")));

#endif
#endif
#if IN_FILE(__GDK_WINDOW_X11_C__)
#undef gdk_x11_window_set_user_time 
extern __typeof (gdk_x11_window_set_user_time) gdk_x11_window_set_user_time __attribute((alias("IA__gdk_x11_window_set_user_time"), visibility("default")));

#undef gdk_x11_window_move_to_current_desktop 
extern __typeof (gdk_x11_window_move_to_current_desktop) gdk_x11_window_move_to_current_desktop __attribute((alias("IA__gdk_x11_window_move_to_current_desktop"), visibility("default")));

#undef gdk_x11_window_foreign_new_for_display 
extern __typeof (gdk_x11_window_foreign_new_for_display) gdk_x11_window_foreign_new_for_display __attribute((alias("IA__gdk_x11_window_foreign_new_for_display"), visibility("default")));

#undef gdk_x11_window_lookup_for_display 
extern __typeof (gdk_x11_window_lookup_for_display) gdk_x11_window_lookup_for_display __attribute((alias("IA__gdk_x11_window_lookup_for_display"), visibility("default")));

#endif
#if IN_FILE(__GDK_XID_C__)
#undef gdk_xid_table_lookup 
extern __typeof (gdk_xid_table_lookup) gdk_xid_table_lookup __attribute((alias("IA__gdk_xid_table_lookup"), visibility("default")));

#undef gdk_xid_table_lookup_for_display 
extern __typeof (gdk_xid_table_lookup_for_display) gdk_xid_table_lookup_for_display __attribute((alias("IA__gdk_xid_table_lookup_for_display"), visibility("default")));

#endif
#endif
#endif
#if IN_HEADER(__GDK_APP_LAUNCH_CONTEXT_H__)
#if IN_FILE(__GDK_APP_LAUNCH_CONTEXT_C__)
#undef gdk_app_launch_context_get_type 
extern __typeof (gdk_app_launch_context_get_type) gdk_app_launch_context_get_type __attribute((alias("IA__gdk_app_launch_context_get_type"), visibility("default")));

#undef gdk_app_launch_context_new 
extern __typeof (gdk_app_launch_context_new) gdk_app_launch_context_new __attribute((alias("IA__gdk_app_launch_context_new"), visibility("default")));

#undef gdk_app_launch_context_set_display 
extern __typeof (gdk_app_launch_context_set_display) gdk_app_launch_context_set_display __attribute((alias("IA__gdk_app_launch_context_set_display"), visibility("default")));

#undef gdk_app_launch_context_set_screen 
extern __typeof (gdk_app_launch_context_set_screen) gdk_app_launch_context_set_screen __attribute((alias("IA__gdk_app_launch_context_set_screen"), visibility("default")));

#undef gdk_app_launch_context_set_desktop 
extern __typeof (gdk_app_launch_context_set_desktop) gdk_app_launch_context_set_desktop __attribute((alias("IA__gdk_app_launch_context_set_desktop"), visibility("default")));

#undef gdk_app_launch_context_set_timestamp 
extern __typeof (gdk_app_launch_context_set_timestamp) gdk_app_launch_context_set_timestamp __attribute((alias("IA__gdk_app_launch_context_set_timestamp"), visibility("default")));

#undef gdk_app_launch_context_set_icon 
extern __typeof (gdk_app_launch_context_set_icon) gdk_app_launch_context_set_icon __attribute((alias("IA__gdk_app_launch_context_set_icon"), visibility("default")));

#undef gdk_app_launch_context_set_icon_name 
extern __typeof (gdk_app_launch_context_set_icon_name) gdk_app_launch_context_set_icon_name __attribute((alias("IA__gdk_app_launch_context_set_icon_name"), visibility("default")));

#endif
#endif
#if IN_HEADER(__GDK_WINDOW_IMPL_H__)
#if IN_FILE(__GDK_WINDOW_IMPL_C__)
#undef gdk_window_impl_get_type 
extern __typeof (gdk_window_impl_get_type) gdk_window_impl_get_type __attribute((alias("IA__gdk_window_impl_get_type"), visibility("default")));

#endif
#endif
#ifdef GDK_WINDOWING_X11
#endif

#endif /* G_HAVE_GNUC_VISIBILITY */
#endif /* DISABLE_VISIBILITY */
